#!/bin/ksh
#***********************************************************************
# Program name  : lbxcrtos.db2                                        *
#                                                                      *
# Description   : This script is for adding DB2 object server          *
#                                                                      *
# Change History: ssw 10/23/97                                         *
#***********************************************************************

if [[ "$FRNDEBUG" = "1" ]]; then set -x; fi   # enable diagnostics

# Display copyright statement
cat $FRNROOT/copyright

# Check for setting of all required environment variables
$FRNROOT/frncheck

if [[ $? -ne 0 ]]; then
   # One or more required environment variables are not set
   return 2
fi

# Setup message variables
. ./frnxcosm.sh

# Check for setting of required environment variable
if [[ ! -d "$FRNROOT" ]]; then
   dspmsg $MSG_MSGFILE $MSG_REQVARNOTSET "$MSG_MSGNOTFOUND" "FRNROOT=$FRNROOT"
   return 1
fi

# Invoke wrapper for this script
if [[ "$FRNRUNTIMES" != "1" ]]; then
  export FRNRUNTIMES=1
  export FRNMYNAME=$1
  filename=${0##*/}                # get filename without leading path
  $FRNROOT/frnxutwp $filename
  return
fi

# Get the name of the instance owner from the DB2INSTANCE environment variable
VALIDVAR=0; # reset edit switch
if [[ "$DB2INSTANCE" != "" ]]; then
   # environment variable set - check if user exists
   id $DB2INSTANCE > /dev/null 2>&1
# MNC - Disable check to prevent root instance for Driver 1, 07/09/95.
#  if [[ $? -ne 0 || "$DB2INSTANCE" = "root" ]]; then
   if [[ $? -ne 0 ]]; then
      dspmsg $MSG_MSGFILE $MSG_BADDB2INSTANCE "$MSG_MSGNOTFOUND" "$DB2INSTANCE"
   else
      VALIDVAR=1
   fi # end of if invalid user
else
   dspmsg $MSG_MSGFILE $MSG_DB2INSTANCEUNDEF "$MSG_MSGNOTFOUND"
fi # end of if environment variable is set

# Check validity of the instance owner and allow installer to correct it
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
   NOANSWER=0;
   if [[ "$VALIDVAR" = 1 ]]; then
      answer=$DB2INSTANCE
   else
      # Get the name of the instance owner from the installer
      dspmsg $MSG_MSGFILE $MSG_ENTERDB2INSTANCE "$MSG_MSGNOTFOUND"
      read answer
      if [[ -z "$answer" ]]; then   # is string missing?
         #A2542.pjs Database not created
         NOANSWER=1
      else
         # installer entered name - check if user exists
         id $answer > /dev/null 2>&1
         if [[ $? -ne 0 ]]; then
            dspmsg $MSG_MSGFILE $MSG_BADUSER "$MSG_MSGNOTFOUND" "$answer"
            NOANSWER=1
         fi # end of if invalid user
      fi # end of if instance owner name was not entered
   fi # end of if valid environment variable

   if [[ "$NOANSWER" = 0 ]]; then
      # Determine the home directory of the instance owner
      INSTHOME=`awk '{FS=":";
                print $1, $6}' /etc/passwd | grep "^$answer " | awk '{print $2}'`
      export INSTHOME

      # Check for existence of database directory
      if [[ -d $INSTHOME/sqllib ]]; then
         # instance owner specified passes all preliminary checks
         VALIDDB=1
         DB2INSTANCE=$answer
         export DB2INSTANCE
      else
         VALIDVAR=0
         dspmsg $MSG_MSGFILE $MSG_USERNOTDB2INSTANCE "$MSG_MSGNOTFOUND" "$answer"
      fi # end of if default data directory exists
   fi # end of if answer or environment variable set
done # end of until done loop

. $INSTHOME/sqllib/db2profile

#confirm that the given database name is ok
dspmsg $MSG_MSGFILE $MSG_OSCONFIRMDBNAME "$MSG_MSGNOTFOUND" "$FRNDBNAME"
read answer
if [[ -n "$answer" ]]            # Something non-null entered, so exit
  then
     # Must run config to change database name
     dspmsg $MSG_MSGFILE $MSG_OSCHANGEDBNAME "$MSG_MSGNOTFOUND" "$FRNROOT"
     return 4
fi

FRNODBNAME=$FRNDBNAME
export FRNODBNAME

usr=`whoami`
usrhome=`grep "^$usr:" /etc/passwd|cut -f6 -d:`
cat /dev/null > $usrhome/sel_objectserver.out 2>&1
cat /dev/null > $usrhome/ins_objectserver.out 2>&1
printf "select max(bos_objectserverid)+1 from base_objectserver" > $usrhome/sel_objectserver.sql
db2start
db2 connect to $FRNODBNAME
db2 -f$usrhome/sel_objectserver.sql -r$usrhome/sel_objectserver.out
if [[ $? -eq 0 ]]; then
   OBJ_ID=`egrep -v "^$|[0-9]  *|---*|record" $usrhome/sel_objectserver.out|sed 's/  *//g'`
   printf "insert into base_objectserver values(%s,'%s',%s)" "$OBJ_ID" "$FRNMYNAME" "0" > $usrhome/ins_objectserver.sql
   db2 -f$usrhome/ins_objectserver.sql -r$usrhome/ins_objectserver.out
   if [[ -$? -eq 0 ]]; then
      dspmsg $MSG_MSGFILE $MSG_DBCREATEDONE "$MSG_MSGNOTFOUND" "$FRNODBNAME"
      rm $usrhome/ins_objectserver.sql $usrhome/sel_objectserver.sql
   else
      dspmsg $MSG_MSGFILE $MSG_NOTCREATED "$MSG_MSGNOTFOUND" "$FRNODBNAME"
   fi
else
   dspmsg $MSG_MSGFILE $MSG_NOTCREATED "$MSG_MSGNOTFOUND" "$FRNODBNAME"
fi

