#!/bin/ksh
#***********************************************************************
# Digital Library Version 2 - 5765-C86.                                *
# VisualInfo Version 2 Release 3.0 - 5697-250.                         *
# (C) Copyright IBM Corp. 1994,1997.                                   *
# All Rights Reserved.                                                 *
#                                                                      *
# US Government Users Restricted Rights                                *
# Use, duplication or disclosure restricted by GSA ADP Schedule        *
# Contract with IBM Corp.                                              *
# Licensed Materials - Property of IBM                                 *
#***********************************************************************
#***********************************************************************
#                                                                      *
# Program name  : altora                                               *
#                                                                      *
# Description   : Alter DL Oracle database                             *
#                 from version 1 to version 2                          *
#                 can be used for either Object or Library server      *
#                                                                      *
# Change History:                                                      *
#  05/30/97       dh new source code                                   *
#                                                                      *
#***********************************************************************

#export FRNROOT=.

# Display copyright statement
cat copyright

# Setup message variables
#. ./frnxcosm.sh

# Ensure that only the oracle user performs migration
user=`whoami`
if [[ $user != "oracle" ]]; then
   echo "\nThe user $user may not perform this alter database function" 
   echo "  Only the oracle user may perform database upgrade, exit "   
   exit 1
fi # end of if current user is not oracle

echo "***********************************************"
echo "**    Oracle Database Upgrade                **"
echo "**    Please select one of the following:    **"
echo "**    1   Upgrade Object Server DB           **"
echo "**    2   Upgrade Library Server DB          **"
echo "**    0   Exit                               **"
echo "***********************************************"
read answer
TGT=$answer
if [[ $TGT = 0 ]]; then
   echo "exit"
   exit
fi
if [[ $TGT != 1 && $TGT != 2 && $TGT != 0 ]]; then
   echo "Invalid selection, exit"
   exit
fi

if [ $TGT = 1 ]; then
   #------------------------------------------------------------------------------
   #  Check for media feature      
   #------------------------------------------------------------------------------
   #dspmsg $MSG_MSGFILE $MSG_MEDIASUPPORT "$MSG_MSGNOTFOUND" \
   echo "\nEnable Media Server support?"
   echo "If yes, type Y, press any other key for no :"
   read answer
   if [[ "$answer" = "y" || "$answer" = "Y" ]]; then
      export medflag=Y
      # Prompt for media server name
      echo "\nEnter the name of your Media Server:"
      #dspmsg $MSG_MSGFILE $MSG_MSNAME "$MSG_MSGNOTFOUND" \
      read msName
      typeset -u msName
      if [[ -z $msName ]]; then
         echo "\nNo Media Server name entered.  Process can not continue"
         #dspmsg $MSG_MSGFILE $MSG_MSNAME_NOTFOUND "$MSG_MSGNOTFOUND" \
         exit
      fi
      export msName
      # Prompt for media server asset group
      echo "\nEnter the name of your Media Asset Group:"
      #dspmsg $MSG_MSGFILE $MSG_MSGROUP "$MSG_MSGNOTFOUND" \
      read msGroup
      typeset -u msGroup
      if [[ -z $msGroup ]]; then
         echo "\nNo Media Asset Group name entered.  Process can not continue"
         #dspmsg $MSG_MSGFILE $MSG_MSGROUP_NOTFOUND "$MSG_MSGNOTFOUND" \
         exit
      fi
      export msGroup
      # Prompt for media server type
      echo "\nEnter the name of Media Server Type:"
      echo "For Media Streamer enter M, any other key for Video Charger"
      #dspmsg $MSG_MSGFILE $MSG_MSTYPE1 "$MSG_MSGNOTFOUND" \
      #dspmsg $MSG_MSGFILE $MSG_MSTYPE2 "$MSG_MSGNOTFOUND" \
      read msType
      if [[ "$msType" = "m" || "$msType" = "M" ]]; then
         msType=M
      else
         msType=V
      fi
      export msType

   else
      export medflag=N   
   fi 
   echo "\nEnter the Object Server database name:" 
else
   echo "\nEnter the Library Server database name:"
fi
read dbname
typeset -u dbname
if [[ -z "$dbname"  ]]; then  # is string missing?
   echo "\nCan not proceed without database name, exit"
   exit
else
   # check to make sure length does not exceed 8 characters+newline
   export FRNDB=$dbname
   export ORACLE_SID=$dbname
fi     # end of if dbname is missing

# check to see if there is an instance with this ORACLE_SID
echo "\nChecking the existence of $FRNDB, please wait ..." 
#dspmsg $MSG_MSGFILE $MSG_DBEXISTCHECK "$MSG_MSGNOTFOUND" "$FRNODBNAME" 
        
oracle_output=`svrmgrl<<- EOF
connect internal;
startup;
select username from user_users;
exit;
EOF`
echo $oracle_output > tmp1
result=`grep ORA- tmp1| wc -l`

started=`grep ORA-01081 tmp1 | wc -l`

if (( started == 1 || ( started == 0 && result == 0 ))); then
   # get the userid for create database tables
   echo "\nEnter the database user id:"
   read answer
   if [[ -z "$answer" ]]; then    # is string missing?
      echo "\nCan not proceed without user id, exit"
      exit 1
   else
      FRNUSERID=$answer
      export FRNUSERID
   fi # end of string mistting

   # get the password for $FRNUSERID
   echo "\nEnter password:"
   stty -echo
   read answer
   stty echo
   echo
   if [[ -z "$answer" ]]; then    # is string missing?
      echo "\nCan not proceed without password, exit"
      exit
   else
      FRNPASSWD=$answer
      export FRNPASSWD
   fi # end of missing string
else
   echo "\nCan not connect to database, make sure it is up before executing this program, exit"
   exit
fi
OUTDIR=`pwd`
cat /dev/null > $OUTDIR/alter.log 2>&1
cat /dev/null > $OUTDIR/alter.sql 2>&1
if [ $TGT = 1 ]; then
   echo "ALTER TABLE BASE_CNTL ADD ("                               >> $OUTDIR/alter.sql 
   echo "     CTL_MPURGERENABLE   CHAR(1)                       , " >> $OUTDIR/alter.sql
   echo "     CTL_MPURGERCYCLE    NUMBER(5,0)                   , " >> $OUTDIR/alter.sql
   echo "     CTL_MDESTAGRENABLE  CHAR(1)                       , " >> $OUTDIR/alter.sql
   echo "     CTL_MDESTAGRCYCLE   NUMBER(5,0)                   , " >> $OUTDIR/alter.sql
   echo "     CTL_MSTAGEBATCHSZE  NUMBER(5,0)                   , " >> $OUTDIR/alter.sql
   echo "     CTL_MEDIACONFIG     CHAR(1)                       );" >> $OUTDIR/alter.sql

   echo "UPDATE BASE_CNTL SET CTL_MPURGERENABLE='N',              " >> $OUTDIR/alter.sql
   echo "                     CTL_MPURGERCYCLE=24,                " >> $OUTDIR/alter.sql
   echo "                     CTL_MDESTAGRENABLE='N',             " >> $OUTDIR/alter.sql
   echo "                     CTL_MDESTAGRCYCLE=24,               " >> $OUTDIR/alter.sql
   echo "                     CTL_MSTAGEBATCHSZE=10,              " >> $OUTDIR/alter.sql
   if [[ "$medflag" = "Y" ]]; then
      echo "                     CTL_MEDIACONFIG='Y';                " >> $OUTDIR/alter.sql
   else
      echo "                     CTL_MEDIACONFIG='N';                " >> $OUTDIR/alter.sql
   fi

   echo "ALTER TABLE BASE_CNTL MODIFY ("                            >> $OUTDIR/alter.sql 
   echo "     CTL_MPURGERENABLE                         NOT NULL, " >> $OUTDIR/alter.sql
   echo "     CTL_MPURGERCYCLE                          NOT NULL, " >> $OUTDIR/alter.sql
   echo "     CTL_MDESTAGRENABLE                        NOT NULL, " >> $OUTDIR/alter.sql
   echo "     CTL_MDESTAGRCYCLE                         NOT NULL, " >> $OUTDIR/alter.sql
   echo "     CTL_MSTAGEBATCHSZE                        NOT NULL, " >> $OUTDIR/alter.sql
   echo "     CTL_MEDIACONFIG                           NOT NULL);" >> $OUTDIR/alter.sql

   echo "CREATE TABLE BASE_OBJECTS_MEDIA                          " >> $OUTDIR/alter.sql             
   echo "  (  MOB_OBJECTNAME      CHAR(44)              NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_COLLECTIONID    NUMBER(5,0)           NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_MGTCLASSID      NUMBER(5,0)           NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_STGCLASSID      NUMBER(5,0)           NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_VOLUMEID        NUMBER(10,0)          NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_PATH            NUMBER(10,0)          NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_FILENAME        CHAR(12),                       " >> $OUTDIR/alter.sql
   echo "     MOB_ATTRIBUTES      NUMBER(5,0)           NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_PLAYSTATUS      CHAR(1),                        " >> $OUTDIR/alter.sql
   echo "     MOB_STAGINGSTATUS   CHAR(1),                        " >> $OUTDIR/alter.sql
   echo "     MOB_VOLSTATUS       CHAR(1),                        " >> $OUTDIR/alter.sql
   echo "     MOB_SIZE            NUMBER                NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_CREATEDATE      DATE                  NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_REFERENCEDDATE  DATE                  NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_ACTIONDATE      DATE                  NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_MGTCLASSDATE    DATE                  NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_STGCLASSDATE    DATE                  NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_RETENTION       NUMBER(10,0)          NOT null, " >> $OUTDIR/alter.sql
   echo "     MOB_LIBRARYID       NUMBER(5,0)           NOT null, " >> $OUTDIR/alter.sql
   echo "     PRIMARY KEY (MOB_OBJECTNAME));                      " >> $OUTDIR/alter.sql

   echo "CREATE TABLE BASE_STAGING_MEDIA                          " >> $OUTDIR/alter.sql
   echo "   ( MST_ID                    NUMBER(5,0)     NOT null, " >> $OUTDIR/alter.sql
   echo "     MST_SIZE                  NUMBER          NOT null, " >> $OUTDIR/alter.sql
   echo "     MST_SPACEUSED             NUMBER          NOT null, " >> $OUTDIR/alter.sql
   echo "     MST_PERCENTSTART          NUMBER(5,0)     Not null, " >> $OUTDIR/alter.sql
   echo "     MST_PERCENTSTOP           NUMBER(5,0)     NOT null, " >> $OUTDIR/alter.sql
   echo "     MST_SERVERACTIVE          CHAR(1)         NOT null, " >> $OUTDIR/alter.sql
   echo "     MST_SERVERNAME            VARCHAR(128),             " >> $OUTDIR/alter.sql
   echo "     MST_SERVERTYPE            CHAR(1)         NOT null, " >> $OUTDIR/alter.sql
   echo "     MST_MEDIAGROUP            VARCHAR(128)    NOT null, " >> $OUTDIR/alter.sql
   echo "     MST_PORTNUMBER            NUMBER(10,0)    Not null, " >> $OUTDIR/alter.sql
   echo "     PRIMARY KEY(MST_ID));                               " >> $OUTDIR/alter.sql
   if [[ "$medflag" = "Y" ]]; then
      echo "INSERT INTO BASE_STAGING_MEDIA                           " >> $OUTDIR/alter.sql
      echo "    VALUES (1,0.0,0.0,80,60,'N','$msName','$msType','$msGroup',23800);" >> $OUTDIR/alter.sql
   else
      echo "INSERT INTO BASE_STAGING_MEDIA                           " >> $OUTDIR/alter.sql
      echo "    VALUES (1,0.0,0.0,80,60,'N','','M','OBJSRVRX',23800);" >> $OUTDIR/alter.sql
   fi
else
   echo "ALTER TABLE SBTCLASSATTRS ADD MVTTABLENAME CHAR(13);"  >> $OUTDIR/alter.sql
fi
OUTMSG=`svrmgrl <<- EOF
connect $FRNUSERID/$FRNPASSWD
spool $OUTDIR/alter.log
@$OUTDIR/alter.sql
spool off
exit;
EOF`
echo $OUTMSG > tmp2
errout=`sed 's/SVRMGR>/\
/g;s/ORA-/\
ORA-/g' tmp2|grep "ORA-"|sed 's/..*ORA/ORA/1;s/:.*//1'`

cnt=`echo $errout|grep "ORA-"|wc -l`
if (( $cnt == 0 )); then
   if [ $TGT = 2 ]; then
      `pwd`/frnxmilt.oracle.exe $FRNDB $FRNUSERID $FRNPASSWD
      if [[ $? -ne 0 ]]; then
         echo "Failed during frnxmilt.oracle.exe"
         echo "however, sbtclassattrs upgraded successfully"
      else
         echo "\nUpgrade database successfully, see alter.log." 
         rm $OUTDIR/alter.sql
      fi
   fi
   if [ $TGT = 1 ]; then
      echo "spool volume.out" >> $OUTDIR/getmax.sql
      echo "select max(vol_volumeid+1) from base_volumes;" >> $OUTDIR/getmax.sql
      echo "spool off" >> $OUTDIR/getmax.sql
      echo "spool devmgr.out" >> $OUTDIR/getmax.sql
      echo "select max(dev_devmgrid+1) from base_devmgr;" >> $OUTDIR/getmax.sql
      echo "spool off" >> $OUTDIR/getmax.sql
      echo "spool stgcls.out" >> $OUTDIR/getmax.sql
      echo "select max(stc_stgclassid+1) from base_storageclass;" >> $OUTDIR/getmax.sql
      echo "spool off" >> $OUTDIR/getmax.sql
      echo "spool stggrp.out" >> $OUTDIR/getmax.sql
      echo "select max(stg_stggroupid+1) from base_storagegroup;" >> $OUTDIR/getmax.sql
      echo "spool off" >> $OUTDIR/getmax.sql
      echo "spool mgtcls.out" >> $OUTDIR/getmax.sql
      echo "select max(mgc_mgtclassid+1) from base_mgtclass;" >> $OUTDIR/getmax.sql
      echo "spool off" >> $OUTDIR/getmax.sql
      echo "spool collid.out" >> $OUTDIR/getmax.sql
      echo "select max(col_collid+1) from base_collections;" >> $OUTDIR/getmax.sql
      echo "spool off" >> $OUTDIR/getmax.sql

svrmgrl<<- EOF
connect $FRNUSERID/$FRNPASSWD
@$OUTDIR/getmax.sql
exit;
EOF

      if [[ $? -eq 0 ]]; then

         devmgrid=`egrep -v 'MAX|^---|selected' devmgr.out| sed "s/^  *//g"`
         stgclsid=`egrep -v 'MAX|^---|selected' stgcls.out| sed "s/^  *//g"`
         stggrpid=`egrep -v 'MAX|^---|selected' stggrp.out| sed "s/^  *//g"`
         mgtclsid=`egrep -v 'MAX|^---|selected' mgtcls.out| sed "s/^  *//g"`
         collid=`egrep -v 'MAX|^---|selected' collid.out| sed "s/^  *//g"`
         volumeid=`egrep -v 'MAX|^---|selected' volume.out| sed "s/^  *//g"`
         echo "spool media.log" > $OUTDIR/mediainfo.sql
         if [[ "$medflag" = "Y" || "$medflag" = "y" ]]; then
            echo "INSERT INTO BASE_DEVMGR VALUES ($devmgrid,'FRNXMADM','00000004','Y','IBM MEDIA ARCHIVER DEVICE MANAGER','');" >> $OUTDIR/mediainfo.sql
         else
            echo "INSERT INTO BASE_DEVMGR VALUES ($devmgrid,'FRNXMADM','00000004','N','IBM MEDIA ARCHIVER DEVICE MANAGER','');" >> $OUTDIR/mediainfo.sql
         fi
         echo "INSERT INTO BASE_STORAGECLASS VALUES ($stgclsid,'MEDIASTC',1,0,'','','',0);" >> $OUTDIR/mediainfo.sql
         echo "INSERT INTO BASE_STORAGEGROUP VALUES ($stggrpid,'MEDIASTG');" >> $OUTDIR/mediainfo.sql
         echo "INSERT INTO BASE_MGTCLASS VALUES ($mgtclsid,'MEDIAMGC',0,0,0);" >> $OUTDIR/mediainfo.sql
         echo "INSERT INTO BASE_MGTTRANSITION VALUES($mgtclsid,1,$stgclsid,1,30,0,12);" >> $OUTDIR/mediainfo.sql
         echo "INSERT INTO BASE_COLLECTIONS VALUES ($collid,'Media.Collectn.Archive',$stggrpid,$mgtclsid);" >> $OUTDIR/mediainfo.sql
         collid=$(($collid + 1))
         echo "INSERT INTO BASE_COLLECTIONS VALUES ($collid,'Media.Collectn.NoArchiv',$stggrpid,$mgtclsid);" >> $OUTDIR/mediainfo.sql
         echo "INSERT INTO BASE_STGCLSDEVMGR VALUES ($stgclsid,$devmgrid);" >> $OUTDIR/mediainfo.sql
         echo "INSERT INTO BASE_STGGRPCLASS VALUES ($stggrpid,$stgclsid);" >> $OUTDIR/mediainfo.sql
         echo "INSERT INTO BASE_VOLUMES VALUES ($volumeid,'MSARCHIV','MSARCHIV','MSARCHIV',$devmgrid,$stgclsid,0,0,0,181,'A',1,TO_DATE(SYSDATE, 'DD-MON-YYYY'), 'Offline');" >> $OUTDIR/mediainfo.sql
         echo "INSERT INTO BASE_STGGRPVOLUME VALUES ($stggrpid, $volumeid);" >> $OUTDIR/mediainfo.sql
         echo "spool off" >> $OUTDIR/mediainfo.sql
         if [[ $? -eq 0 ]]; then
svrmgrl<<- EOF
connect $FRNUSERID/$FRNPASSWD
@mediainfo.sql
exit;
EOF
            if [[ $? -eq 0 ]]; then
               echo "Finish adding media info to database tables"
               echo "Database upgrade has been completed successully!"
               rm *.out *.sql
            else
               echo "Error encountered while adding media info to database tables"
               echo "however, database tables have been upgraded successfully"
            fi
         else
            echo "Error encountered while building mediainfo.sql file"
            echo "however, database has been upgraded successfully"
         fi
      else
         echo "Error encountered when getting max_id from database tables, "
         echo "however, database has been upgraded successfully"
      fi
   fi
else
   echo "\nUpgrate database failed, error code $errout."
fi
rm tmp1 tmp2 > /dev/null 2>&1   
