#!/bin/ksh
#***********************************************************************
# Digital Library Version 2 - 5765-C86.                                *
# VisualInfo Version 2 Release 3.0 - 5697-250.                         *
# (C) Copyright IBM Corp. 1994,1997.                                   *
# All Rights Reserved.                                                 *
#                                                                      *
# US Government Users Restricted Rights                                *
# Use, duplication or disclosure restricted by GSA ADP Schedule        *
# Contract with IBM Corp.                                              *
# Licensed Materials - Property of IBM                                 *
#***********************************************************************
#***********************************************************************
#                                                                      *
# Program name  : frnexport.lib                                        *
#                                                                      *
# Description   : Library Server database migration                    *
#                                                                      *
#***********************************************************************

#export FRNROOT=.

# Display copyright statement
cat copyright

# Setup message variables
#. frnxcosm.sh

echo "\nEnter Library Server database name: "
read answer
if [ -z "$answer" ]; then
   echo "\nCan not proceed without Library Server database name, exit"
   exit 1
else
   export FRNDB=$answer
fi
echo "\nEnter DB2 instance: "
read answer
if [ -z "$answer" ]; then
   echo "\nCan not proceed without DB2 instance name, exit "
else
   export DB2INSTANCE=$answer
fi
#locate instance home directory
INSTHOME=`grep "^$DB2INSTANCE:" /etc/passwd|cut -f6 -d:`
export INSTHOME

export EXPDIR=`pwd`

EXPDIR=`pwd`/exp
NODATA=`pwd`/nodata
#create directories if they do not exist
if [ -d $EXPDIR ]; then
   rm $EXPDIR/*  > /dev/null 2>&1
else
   mkdir $EXPDIR > /dev/null 2>&1
   echo "\nDirectory $EXPDIR did not exist, the migration "
   echo "  program created a $EXPDIR directory. "
fi
if [ -d $NODATA ]; then
   rm $NODATA/* > /dev/null 2>&1
else
   mkdir $NODATA
   echo "\nDirectory $NODATA did not exist, the migration "
   echo "  program created a $NODATA directory. "
fi

#create sql files
echo select name \\  >avttbl.sh
echo from SYSIBM.SYSTABLES where name like \'AVT%\' >> avttbl.sh

echo select text from SYSIBM.SYSVIEWS where \\  >icvtbl.sh
echo name like \'ICV%\' and valid =\'Y\' and name \> \'ICV00007\' >> icvtbl.sh

echo select name \\ >basetbl.sh
echo   from SYSIBM.SYSTABLES where name like \'SBT%\' >> basetbl.sh

echo select reftbname, tbname from SYSIBM.SYSRELS > myrel.sh

#get db config
echo "get db cfg for $FRNDB" > dbcfg.sql

cat /dev/null > $EXPDIR/dbcfg.lst

#cd /usr/lpp/frn/bin
. $INSTHOME/sqllib/db2profile
db2 db2start
#get db config
db2 -fdbcfg.sql -r$EXPDIR/dbcfg.lst
db2 connect to $FRNDB
#get all AVT tables from database
db2 -favttbl.sh -ravt.lst
#get all ICV views from database
db2 -ficvtbl.sh -ricv.lst
#get all base(SBT) tables from database
db2 -fbasetbl.sh -rbasetbl.lst
#get relational constraint from system table reltables
db2 -fmyrel.sh  -rrel.lst


#get all user created tables other than base tables
egrep -v "^NAME|^---|record\(s\) selected|AVT0000[0-7]|^$" avt.lst > $EXPDIR/extratbl.lst
#use icv.lst to build a cmd file to get view info

cut -c1-2040 icv.lst|egrep -v "^TEXT|^---|record\(s\) selected|^$"|sed 's/    *//g' > $EXPDIR/icvextra.lst
#cut -c1-2040 icv.lst|egrep -v "^TEXT|^---|record\(s\) selected|^$"|sed 's/    *//g;s/$/;/g' > $EXPDIR/icvextra.lst

#create a file full.lst with all the database table names
cat avt.lst basetbl.lst|egrep -v "^NAME|^---|record\(s\) selected|^$|SBTLICENSEKEY|SBTLICVIOLATIONS" > full.lst

#the purpose of the following steps is to ensure the sequence of either
#create table or insert rows is following the rule of integrity constraint
#if the same table name appears in the 2nd column of rel.lst more than once
#we keep only the last one, replace others lines with blanks
#new.rel.lst is the output file after cut and paste

egrep -v "^$|^----|REFTBNAME|record" rel.lst|sed 's/  */,/g' > rel1.lst
cut -d"," -f2 rel1.lst > reltbl.lst
cut -d"," -f1 rel1.lst > relref.lst
old=`head -1 reltbl.lst`
sed '1d' reltbl.lst > rel.tbl.lst
totline=`cat rel.tbl.lst|wc -l`
cnt=1
rm new.tbl.lst > /dev/null 2>&1
for i in `cat rel.tbl.lst`
   do
      new=`echo $i`
      if [ $cnt -ne $totline ]; then
         if [ $new = $old ]; then
            echo " " >> new.tbl.lst
         else
            echo $old >> new.tbl.lst
         fi
         old=$new
         cnt=$cnt+1
      else
         if [ $new = $old ]; then
            echo " " >> new.tbl.lst
            echo $new >> new.tbl.lst
         else
            echo $old >> new.tbl.lst
            echo $new >> new.tbl.lst
         fi
      fi
   done

paste -d" " relref.lst new.tbl.lst > new.rel.lst

#change file from 2 columns to 1 column, get rid of blank lines
sed 's/  */\
/g' new.rel.lst | grep -v "^$"  > relation.lst
#delete duplicate tablename keep constraint order
#at this point, only the reference tables can have duplicates
cat /dev/null > constraint.lst
cat /dev/null > noconstraint.lst
for i in `cat relation.lst`
do
   num=`grep $i constraint.lst| wc -l`
   if (( $num == 0 )); then
      echo $i >> constraint.lst
   fi
done
#here is the list of tables which dont have constraint
for i in `cat full.lst`
do
  num=`grep $i constraint.lst|wc -l`
  if (( num == 0)); then
     echo $i >> noconstraint.lst
  fi
done
#whole.lst and full.lst have same content, but whole.lst has the correct order
cat constraint.lst noconstraint.lst > 1stwhole.lst

cat /dev/null > $EXPDIR/part.lst
for i in `cat 1stwhole.lst`
do
   cnt=`grep $i $EXPDIR/extratbl.lst|wc -l`
   if (( cnt == 0 )); then
      echo $i >> $EXPDIR/part.lst
   fi
done 
cat $EXPDIR/part.lst $EXPDIR/extratbl.lst > 2ndwhole.lst

#use 2ndwhole.lst to build a cmd file to export database data
cat /dev/null > export.file
cat /dev/null > avtdef.file
cat /dev/null > /tmp/export.log

for i in `cat $EXPDIR/extratbl.lst`
   do
        echo EXPORT TO $EXPDIR/$i.def.ixf OF IXF messages $EXPDIR/$i.def.msg SELECT \* FROM ROOT.$i where 1=0 >> avtdef.file
   done

for i in `cat 2ndwhole.lst`
   do
        echo EXPORT TO $EXPDIR/$i.ixf OF IXF messages $EXPDIR/$i.msg SELECT \* FROM ROOT.$i >> export.file
   done

echo "Exporting index class definitions..."
db2 -favtdef.file -z/tmp/avtdef.file

echo "Library Server database export in process, please wait"

db2 -fexport.file  -z/tmp/export.log

if [[ $? -ne 0 ]]; then
   echo "Error occurred while exporting data"
   exit 1
else
   echo "Export data finished, see /tmp/export.log."
fi
rm avttbl.sh basetbl.sh myrel.sh avt.lst basetbl.lst rel.lst append.lst append.icv full.lst relation.lst constraint.lst noconstraint.lst export.file getindex.cmd extratabdef.lst index.file index.info create.idx new.rel.lst dbcfg.sql > /dev/null 2>&1
rm new.tbl.lst rel.tbl.lst rel1.lst relref.lst reltbl.lst createtbl.sh createtbl extratabdef.asc icv.lst icvtbl.sh > /dev/null 2>&1
rm rel1.lst reltbl.lst relref.lst rel.tbl.lst new.tbl.lst extratbl.sql 1stwhole.lst 2ndwhole.lst createtbl1 > /dev/null 2>&1
rm icvextra.* create.tmp > /dev/null 2>&1

