#!/bin/ksh
#***********************************************************************
# Digital Library Version 2 - 5765-C86.                                *
# VisualInfo Version 2 Release 3.0 - 5697-250.                         *
# (C) Copyright IBM Corp. 1994,1997.                                   *
# All Rights Reserved.                                                 *
#                                                                      *
# US Government Users Restricted Rights                                *
# Use, duplication or disclosure restricted by GSA ADP Schedule        *
# Contract with IBM Corp.                                              *
# Licensed Materials - Property of IBM                                 *
#***********************************************************************
#***********************************************************************
# Program name  : frnxmile.oracle.sh 
#***********************************************************************
#                                                                      *
# Description   : Database Migration from AIX Oracle DL V1             *
#                                     to  NT  Oracle DL V2             *
#                                                                      *
#***********************************************************************
#export FRNROOT=.

# Display copyright statement
cat copyright

# Setup message variables
#. frnxcosm.sh

user=`whoami`
if [[ $user != "oracle" ]]; then
   echo "Only the user oracle may perform database migration, exit."
   exit 1
fi # end of if current user is not oracle

# Setup variables

# Get a valid database name from the installer
VALIDDB=0; # reset edit switch
getinput=1

if [[ "$1" != "" ]]; then
   getinput=0
fi # endof if database name was entered on command line
until [[ "$VALIDDB" = 1 ]]; do
   if [[ getinput -ne 0 ]]; then
      # determine the name of the database to create
echo  "Enter the Library Server database name: "
#      dspmsg $MSG_MSGFILE $MSG_GETDBNAME2 "$MSG_MSGNOTFOUND"
      read dbname
      typeset -u dbname
      if [[ -z "$dbname"  ]]; then  # is string missing?
         VALIDDB=1
         echo  "Can not proceed without database name, exit."
#         dspmsg $MSG_MSGFILE $MSG_NODBNAME "$MSG_MSGNOTFOUND"
         exit 1
      else
           VALIDDB=1
            export FRNODBNAME=$dbname
            export ORACLE_SID=$dbname
            echo "Enter database user id:"
            read answer
            if [[ -z "$answer" ]]; then
               echo "Can not proceed without table owner id, exit\n"
               #dspmsg $MSG_MSGFILE $MSG_NOUSERID "$MSG_MSGNOTFOUND"
               exit 1
            else
               export ORAID=$answer
            fi
            echo "Enter password:"
            stty -echo
            read answer
            stty echo
            echo
            if [[ -z "$answer" ]]; then
               echo "Can not run migration without $ORAID's password\n"
#               dspmsg $MSG_MSGFILE $MSG_NOPASSWORD "$MSG_MSGNOTFOUND"
               exit 1
            else
               export ORA_PWD=$answer
            fi

       fi
    else
       getinput=1
    fi
done

if [[ -f exp.log ]]; then
   mv exp.log exp.log.old > /dev/null 2>&1
   if [[ $? -eq 0 ]]; then
      echo "The existing exp.log is renamed to exp.log.old\n"
#      dspmsg $MSG_MSGFILE $MSG_LOGRENAMED "$MSG_MSGNOTFOUND"
      date > exp.log
   else
      echo "Error occurred while rename exp.log to exp.log.old"
      exit 1
   fi
fi
# check to see if there is an instance with this ORACLE_SID
echo "Checking the existence of $FRNODBNAME, please wait ..."
#dspmsg $MSG_MSGFILE $MSG_DBEXISTCHECK "$MSG_MSGNOTFOUND" "$FRNODBNAME"
oracle_output=`svrmgrl<<- EOF
connect internal;
startup;
select username from user_users;
exit;
EOF`
result=`echo $oracle_output | grep ORA- | wc -l`
dbaerr=`echo $oracle_output | grep DBA- | wc -l`
started=`echo $oracle_output | grep ORA-01081 | wc -l`

#database either already started or is now startup
if (( started == 1 || ( result ==0 && dbaerr == 0 ))); then
   #now, create a list of constraints that need to be disabled before export data
svrmgrl<<- EOF
spool mytmp.sql;
connect $ORAID/$ORA_PWD
select 'alter table '||table_name||' disable constraint '||constraint_name||' cascade;' from user_constraints;
spool off;
exit;
EOF
   cnt=`grep ORA- mytmp.sql|wc -l`
   if (( $cnt != 0 )); then
      echo "Error occurred when generate constraints list"
      exit 1
   fi
   grep  "alter table" mytmp.sql > expdisable.sql
   if [[ $? -ne 0 ]]; then
      echo "Error occurred when generate command file"
      exit 1
   fi
svrmgrl <<- EOF
connect $ORAID/$ORA_PWD
spool expdisable.log;
@expdisable.sql;
spool off;
exit;
EOF

   cnt=`grep "ORA-" expdisable.log|wc -l`
   if (( $cnt != 0 )); then
      echo "Error occurred while disable table constraints, see expdisable.log"
      exit 1
   fi
   rm mytmp.sql expdisable.sql expdisable.log > /dev/null 2>&1
   #now, export data from database
   exp $ORAID/$ORA_PWD FILE=exp.dmp COMPRESS=Y OWNER=$ORAID LOG=exp.log STATISTICS=estimate >/dev/null 2>&1 
   #Error code prefix for export can be ORA, EXP
   experr=`egrep 'ORA-|EXP-' exp.log|wc -l`
   if (( experr == 0 )); then  #export successfully
svrmgrl<<- EOF
connect $ORAID/$ORA_PWD;
spool tmp1.sql
select 'alter table '||table_name||' enable constraint '||constraint_name||';' from user_constraints where constraint_type='P';
select 'alter table '||table_name||' enable constraint '||constraint_name||';' from user_constraints where constraint_type='U';
select 'alter table '||table_name||' enable constraint '||constraint_name||';' from user_constraints where constraint_type='R';
select 'alter table '||table_name||' enable constraint '||constraint_name||';' from user_constraints where constraint_type='C';
select 'alter table '||table_name||' enable constraint '||constraint_name||';' from user_constraints where constraint_type='V';
spool off;
exit;
EOF
      cnt1=`grep "ORA-" tmp1.sql|wc -l`
      if (( $cnt1 != 0 )); then
         echo "Error occurred while generate enable constraints list"
         exit 1
      fi
      grep  "alter table" tmp1.sql > expenable.sql
      if [[ $? -ne 0 ]]; then
         echo "Error occurred while create constraint enabling list"
         exit 1
      fi
      #enable constraints
svrmgrl <<- EOF
connect $ORAID/$ORA_PWD;
spool expenable.log;
@expenable.sql;
spool off;
exit;
EOF
      cnt2=`grep "ORA-" tmp1.sql|wc -l`
      if (( $cnt2 != 0 )); then
         echo "Error occurred while enable constraints, see expenable.log. "
         exit 1
      fi
      rm tmp1.sql expenable.log expenable.sql > /dev/null
      echo "Export data from database successfully...."
      #dspmsg $MSG_MSGFILE $MSG_EXPORTDONE "$MSG_MSGNOTFOUND"
   else
      echo "Error occurred while export data, see exp.log"
   fi
else
   echo "Error startup database"
   exit 1
fi   
