#!/bin/ksh
#***********************************************************************
# Digital Library Version 2 - 5765-C86.                                *
# VisualInfo Version 2 Release 3.0 - 5697-250.                         *
# (C) Copyright IBM Corp. 1994,1997.                                   *
# All Rights Reserved.                                                 *
#                                                                      *
# US Government Users Restricted Rights                                *
# Use, duplication or disclosure restricted by GSA ADP Schedule        *
# Contract with IBM Corp.                                              *
# Licensed Materials - Property of IBM                                 *
#***********************************************************************
#***********************************************************************
#                                                                      *
# Program name  : frnxmilu.db2.sh                                      *
#                                                                      *
# Description   : Library Server database migration                    *
#                 from AIX DB2 to Oracle.                              *
#                                                                      *
#***********************************************************************

# Check for setting of all required environment variables
#frncheck

#if [[ $? -ne 0 ]]; then
   # One or more required environment variables are not set
#   exit 1
#fi # end of if any required environment variables not set

# Display copyright statement
cat copyright

# Setup message variables
#. $FRNROOT/frnxcosm.sh

echo "Enter DB2 database name: \c"
#dspmsg $MSG_MSGFILE $MSG_READDBNAME2 "$MSG_MSGNOTFOUND"
read answer
if [ -z "$answer" ]; then
   echo "Can not proceed without DB2 database name, exit"
   #dspmsg $MSG_MSGFILE $MSG_NODBNAME "$MSG_MSGNOTFOUND"
   exit 1
else
   export FRNDB=$answer
fi
echo "Enter DB2 instance: \c"
#dspmsg $MSG_MSGFILE $MSG_READDBINSTANCE "$MSG_MSGNOTFOUND"
read answer
if [ -z "$answer" ]; then
     echo "Can not proceed with a DB2 instance name, exit"
     #dspmsg $MSG_MSGFILE $MSG_NODBINSTANCE "$MSG_MSGNOTFOUND"
else
   export DB2INSTANCE=$answer
fi
#locate user home directory
INSTHOME=`grep "^$DB2INSTANCE:" /etc/passwd|cut -f6 -d:`
export INSTHOME

EXPDIR=`pwd`/exp
NODATA=`pwd`/nodata
#create directories if they do not exist
if [ -d $EXPDIR ]; then
   rm $EXPDIR/*  > /dev/null 2>&1
else
   mkdir $EXPDIR > /dev/null 2>&1
   echo "Migration program created a $EXPDIR directory "
   #dspmsg $MSG_MSGFILE $MSG_DIRCREATED "$MSG_MSGNOTFOUND" "$EXPDIR"
fi
if [ -d $NODATA ]; then
   rm $NODATA/* > /dev/null 2>&1
else
   mkdir $NODATA
   echo "Migration program created a $NODATA directory "
   #dspmsg $MSG_MSGFILE $MSG_DIRCREATED "$MSG_MSGNOTFOUND" "$NODATA"
fi

i=0
until [[ "$i" = 1 ]];
do
   echo "Enter Oracle Library Server database platform:"
   echo "0  Exit"
   echo "1  NT"
   echo "2  AIX"
   echo "Selection :  \c"
   read answer
   if (( $answer > 2 )); then
      echo "   Invalid selection, try again !"
      sleep 1
   else
      echo
      i=1
   fi
done
if [[ $answer = 0 ]]; then
    echo "\n   Exit."
   exit
fi
if [[ $answer = 1 ]]; then
   SQLLD=sqlldr73
   USR=%1
   PWD=%2
fi
if [[ $answer = 2 ]]; then
   SQLLD=sqlload
   USR=\$1
   PWD=\$2
fi

function fixdec
{
  befnum=${i%\(*}
  afterscl=${i##*\)}
  if [ "$afterscl" = "," ]; then
     i=${i%\,}
  fi
  nums=${i##*\(}
  prc=${nums%\,*}
  scl=${nums##*\,}
  prc=${prc%\,*}
  if [ "$prc" = "$nums" ]; then
     prc=${nums%\)}
  fi
  if [ "$scl" = "$nums" ]; then
     scl=0
  fi
  scl=${scl%\)*}
  if [ "$scl" = "" ]; then
     scl=0
  fi
  prc=${prc%\)*}
  if [ "$scl" = "0" ]; then
    let prc=$prc+1
    scl=1
  else
    let prc=$prc+1
    let scl=$scl+1
  fi
  repl=''$befnum'('$prc','$scl')'$afterscl''
}


#create sql files
echo select name \\  > avttbl.sh
echo from SYSIBM.SYSTABLES where name like \'AVT%\' >> avttbl.sh

echo select text from SYSIBM.SYSVIEWS where \\  >icvtbl.sh
echo name like \'ICV%\' and valid = \'Y\' and name \> \'ICV00007\' >> icvtbl.sh

echo select name \\ >basetbl.sh
echo   from SYSIBM.SYSTABLES where name like \'SBT%\' >>basetbl.sh

echo select reftbname, tbname from SYSIBM.SYSRELS > myrel.sh

#cd /usr/lpp/frn/bin
. $INSTHOME/sqllib/db2profile
db2 db2start
db2 connect to $FRNDB
#get all AVT tables from database
db2 -favttbl.sh > avt.lst
#get all ICV views from database
db2 -ficvtbl.sh -ricv.lst
#get all base(SBT) tables from database
db2 -fbasetbl.sh > basetbl.lst
#get relational constraint from system table reltables
db2 -fmyrel.sh > rel.lst

#get all user created tables other than base tables
egrep -v "^NAME|^---|record\(s\) selected|AVT0000[0-7]|^$" avt.lst > extratbl.lst
#use icv.lst to build a cmd file to get view info
cut -c1-2040 icv.lst|egrep -v "^TEXT|^---|record\(s\) selected|^$"|sed 's/    *//g;s/$/;/g' > icvextra.lst

#create a file full.lst with all the database table names
cat avt.lst basetbl.lst|egrep -v "^NAME|^---|record\(s\) selected|^$|SBTLICENSEKEY|SBTLICVIOLATIONS" > full.lst

#Make sure the sequence of either create table or insert rows is follow 
#the rule of integrity constraint
#if one table name appears more than once in the 2nd column of rel.lst
#we keep the one appears last (replace others lines with blanks)
#new.rel.lst is the output file after cut and paste
egrep -v "^$|^----|REFTBNAME|record" rel.lst|sed 's/  */,/g' > rel1.lst
cut -d"," -f2 rel1.lst > reltbl.lst
cut -d"," -f1 rel1.lst > relref.lst
old=`head -1 reltbl.lst`
sed '1d' reltbl.lst > rel.tbl.lst
totline=`cat rel.tbl.lst|wc -l`
cnt=1
rm new.tbl.lst > /dev/null 2>&1
for i in `cat rel.tbl.lst`
   do
      new=`echo $i`
      if [ $cnt -ne $totline ]; then
         if [ $new = $old ]; then
            echo " " >> new.tbl.lst
         else
            echo $old >> new.tbl.lst
         fi
         old=$new
         cnt=$cnt+1
      else
         if [ $new = $old ]; then
            echo " " >> new.tbl.lst
            echo $new >> new.tbl.lst
         else
            echo $old >> new.tbl.lst
            echo $new >> new.tbl.lst
         fi
      fi
   done

paste -d" " relref.lst new.tbl.lst > new.rel.lst
rm rel1.lst reltbl.lst relref.lst rel.tbl.lst new.tbl.lst

#change file from 2 columns to 1 column, get rid of blank lines
sed 's/  */\
/g'| grep -v "^$" new.rel.lst > relation.lst
#delete duplicate tablename keep constraint order
#at this point, only the reference tables can have duplicates
cat /dev/null > constraint.lst
cat /dev/null > noconstraint.lst
for i in `cat relation.lst`
do
   num=`grep $i constraint.lst| wc -l`
   if (( $num == 0 )); then
      echo $i >> constraint.lst
   fi
done
#here is the list of tables do not have constraint
for i in `cat full.lst`
do
  num=`grep $i constraint.lst|wc -l`
  if (( num == 0)); then
     echo $i >> noconstraint.lst
  fi
done
#whole.lst is the same as full.lst but whole.lst has the correct order
cat constraint.lst noconstraint.lst > whole.lst
#use whole.list to build a cmd file to get all table info
sed "s/^/select tbname, name, coltype, length, scale, nulls, keyseq, colno from SYSIBM.SYSCOLUMNS where tbname = \'/g;s/$/\' order by colno/g" whole.lst > whole.sql

#use whole.lst to build a cmd file to export database data
cat /dev/null > export.file
egrep -v "SBTPATRONS|SBTPRIVILEGES|SBTDESCRIPTIONS" whole.lst > whole.ascii.lst
for i in `cat whole.ascii.lst`
   do
        echo EXPORT TO $EXPDIR/$i.del OF DEL MODIFIED BY CHARDEL\| DATESISO DECPLUSBLANK SELECT \* FROM \"ROOT\".$i >> export.file
   done

echo select \* from \"ROOT\".SBTPRIVILEGES > sel1
echo select \* from \"ROOT\".SBTPATRONS > sel2
echo select \* from \"ROOT\".SBTDESCRIPTIONS > sel3

db2 connect to $FRNDB
db2 -fsel1 > privilege.dat
db2 -fsel2 > patron.dat
db2 -fsel3 > descr1
cut -c1-2047 descr1 > descriptions.dat


egrep -v "PRIVCODE|selected|----|^$" privilege.dat|sed "s/^  *//1;s/  */,|/1;s/  */|,|/1;s/  *$/|/1;s/'  */|,|/g;s/|x'/|/g" > $EXPDIR/SBTPRIVILEGES.del

egrep -v "USERID|selected|----|^$" patron.dat|sed "s/^  *//g;s/'   */|,/g;s/  */,/g;s/x'/|/g" > $EXPDIR/SBTPATRONS.del

egrep -v "ITEMID|selected|----|^$" descriptions.dat | sed "s/^   *//1;s/   */,/1;s/\([0-9][0-9]*\)  */\1,|/1;s/\([0-9][0-9]*\)  */\1|,|/1;s/  *$/|/g" > $EXPDIR/SBTDESCRIPTIONS.del

cat /dev/null > getindex.cmd
cat /dev/null > /tmp/export.log 
#create a command file to get index info on extra user tables
for i in `cat extratbl.lst`
   do
      echo SELECT UNIQUERULE, NAME, TBNAME, COLNAMES, COLCOUNT FROM SYSIBM.SYSINDEXES WHERE TBNAME=\'$i\' AND UNIQUERULE \<\> \'P\' ORDER BY TBNAME >> getindex.cmd
   done

db2 connect to $FRNDB
db2 -fwhole.sql > tabdef.lst
db2 -fexport.file  > /tmp/export.log
db2 -fgetindex.cmd > index.file

echo Database export completed
echo Formatting data .... please wait

egrep -v "^--|selected|TBNAME|SBTLICENSEKEY|SBTLICVIOLATIONS" tabdef.lst | sed 's/  */,/g' > tabdef.asc

cat /dev/null > createtbl
#build a command file to create user tables (AVT, ICV) in oracle
for i in `cat extratbl.lst`
   do
      echo CREATE TABLE $i\( >> createtbl
      grep $i tabdef.asc|cut -f2-7 -d,|sed 's/,Y,/,/g;s/-$//g;s/,/\(/2;s/,/\),/3;s/,,*$//g;s/\([1-9][0-9]*\),0)/\1)/g' > create.tmp
      cnt=`cat create.tmp|wc -l`
      let j=0
      for line in `cat create.tmp`
         do
            let j=j+1
            if (( j == cnt )); then
                echo $line >> createtbl
            else
                echo $line, >> createtbl
            fi
         done
         let j=0
         echo \)\; >> createtbl
   done

sed 's/  *$//g;s/,N,1$/ PRIMARY KEY/g;s/,N,1,/ PRIMARY KEY,/g;s/,N$/ NOT NULL/g;s/,N,$/ NOT NULL,/g;s/,N,/ NOT NULL /g;s/,/ /1' createtbl > createtbl1

cut -d" " -f1 createtbl1 > crt1
cut -d" " -f2 createtbl1 > crt2
cut -d" " -f3-4 createtbl1 > crt3
cat /dev/null > crt4

for i in `cat crt2`
  do
   echo $i|grep DECIMAL > /dev/null 2>&1
   if [[ $? -eq 0 ]]; then
     fixdec
     echo $repl >> crt4
   else
     echo $i >> crt4
   fi
done
paste -d" " crt1 crt4 crt3|sed 's/); ); );/);/g' > createtbl.tmp

sed 's/INTEGER([0-9][0-9]*)/NUMBER(10,0)/g;s/SMALLINT([0-9][0-9]*)/NUMBER(5,0)/g;s/DECIMAL/NUMBER/g;s/DOUBLE/FLOAT/g;s/REAL/FLOAT/g' createtbl.tmp > createtbl2

sed 's/TIMESTMP([0-9][0-9]*)/CHAR(26)/g;s/TIME([0-9][0-9]*)/CHAR(8)/g;s/DATE([0-9][0-9]*)/CHAR(10)/g' createtbl2 > createtbl.sql

cat /dev/null > $EXPDIR/create.oratbl.sql

egrep -v "^--|selected|TBNAME|^$" index.file |sed 's/  */,/g' > index.info
linecnt=`cat index.info|wc -l`
if (( linecnt == 0 )); then
   cat createtbl.sql icvextra.lst  > create.oratbl.sql
else
#build a command file to create extra index files
   sed 's/^U/CREATE UNIQUE INDEX/g;s/^D/CREATE INDEX/g' index.info| cut -f1-4 -d,|sed 's/,/,ON /2;s/$/ \)/g;s/,/\(/3;s/,/ /g;s/+[A-Z][A-Z]*[0-9][0-9]*/& asc/g;s/-[A-Z][A-Z]*[0-9][0-9]*/& desc/g;s/[+-]/,/g;s/(,/( /g;s/$/\
TABLESPACE objndx;/g' > create.idx
   cat createtbl.sql create.idx icvextra.lst > create.oratbl.sql
fi
#build a list of table names -control.list- without empty tables
cat /dev/null > ctl.lst
for filenm in `cat whole.lst`
  do
    if [ -s $EXPDIR/$filenm.del ];
    then
       echo $filenm.del  >> ctl.lst
#use sed to remove extra space inside of the end quote, also, null starting
#can not be loaded in Oracle column defined as not null
sed "s/$/,/g;s/   *|/|/g" $EXPDIR/$filenm.del > $EXPDIR/$filenm.tmp
sed "s/,||/,| |/g;s/^||,/| |,/g" $EXPDIR/$filenm.tmp > $EXPDIR/$filenm.dat

       if [ $? -eq 0 ]; then
          echo $filenm.dat created
          rm $EXPDIR/$filenm.tmp $EXPDIR/$filenm.tmp1 > /dev/null 2>&1
       else
          echo "Failed to store $filenm.dat in $EXPDIR"
          #dspmsg $MSG_MSGFILE $MSG_STOREFAIL "$MSG_MSGNOTFOUND" $filenm.dat "$EXPDIR"
       fi
    else
       mv $EXPDIR/$filenm.del $NODATA
    fi
 done
cut -d\. -f1 ctl.lst > control.list

#all AVT tables have character columns, no need to format
grep "AVT" tabdef.asc > tabdef.date.asc
grep -v "AVT" tabdef.asc|sed 's/,DATE,/%DATE%\"MM\/DD\/YYYY\",DATE,/g' >> tabdef.date.asc

cat /dev/null > $EXPDIR/load.sql
cat /dev/null > tmp.ctl
cat /dev/null > tmp1.ctl
for i in `cat control.list`
   do
      echo $SQLLD userid=$USR/$PWD control=exp\/$i\.ctl log=exp\/$i\.log >> $EXPDIR/load.sql
      echo LOAD DATA > tmp1.ctl
      echo INFILE \'exp\/$i.dat\' >> tmp1.ctl
      echo APPEND INTO TABLE $i >> tmp1.ctl
      echo FIELDS TERMINATED BY \",\" OPTIONALLY ENCLOSED BY \"\|\" \( >> tmp1.ctl
      grep $i tabdef.date.asc|cut -f2 -d, > tmp.ctl
      cnt1=`cat tmp.ctl|wc -l`
      let k=0
      for line in `cat tmp.ctl`
         do
            let k=k+1
            if (( k == cnt1 )); then
                #$line has a comma in between column name and datatype
                #after echo command, the comma is no longer needed
                echo $line| sed 's/,/ /;s/%/ /g' >> tmp1.ctl
            else
                #remove the comma between fields, and add a comma at the
                #end of each line except the last line of the table
                echo $line| sed 's/,/ /;s/$/,/;s/%/ /g' >> tmp1.ctl
            fi
         done
         let k=0
      echo \) >> tmp1.ctl
      mv tmp1.ctl $EXPDIR/$i.ctl
      echo $i.ctl created
   done

mv create.oratbl.sql $EXPDIR/create.oratbl.sql
rm avttbl.sh icvtbl.sh icv.lst basetbl.sh myrel.sh avt.lst basetbl.lst rel.lst createtbl extratbl.lst full.lst relation.lst constraint.lst noconstraint.lst whole.lst whole.sql export.file getindex.cmd tabdef.lst index.file tabdef.asc index.info create.idx create.tmp createtbl.sql tmp.ctl control.list tabdef.date.asc ctl.lst new.rel.lst > /dev/null 2>&1
rm new.rel.list new.tbl.lst rel.tbl.lst rel1.lst relref.lst reltbl.lst sel1 sel2 sel3 whole.ascii.lst descr1 descriptions.dat privilege.dat patron.dat createtbl1 createtbl2 crttbl.tmp createtbl.tmp createtbl.tmp1 crt? icvextra.* create.tmp > /dev/null 2>&1
echo See /tmp/export.log for export information
