#!/bin/ksh
#***********************************************************************
# Program name  : frnxmioi.db2.sh                                      *
#                                                                      *
# Description   : Object server database migration                     *
#                     from AIX DB2 DL V1 to V2                         *
#***********************************************************************
cat copyright

echo "\nEnter Object Server database name: "
read dbname
if [ -z "$dbname" ]; then
   echo "\nCan not proceed without Object Server database name, exit"
   exit 1
else
   typeset -u dbname
   export FRNDB=$dbname
fi
echo "\nEnter DB2 instance: "
read answer
if [ -z "$answer" ]; then
   echo "\nCan not proceed without DB2 instance name, exit "
else
   export DB2INSTANCE=$answer
fi
 
#locate instance home directory
INSTHOME=`grep "^$DB2INSTANCE:" /etc/passwd|cut -f6 -d:`
export INSTHOME
. $INSTHOME/sqllib/db2profile

export EXPDIR=`pwd`/exp

echo $EXPDIR

IMPLST=$EXPDIR/imp.cmd
cat /dev/null > $EXPDIR/imp.cmd
cat /dev/null > $EXPDIR/runstat.sql
cat /dev/null > $EXPDIR/runstat.log
TBLLST=$EXPDIR/obj_tbl.lst

if [[ -d $EXPDIR ]]; then
   # 7228 begin
   # query base_cntl, get ctl_mediaconfig
   echo "select ctl_mediaconfig from base_cntl" > cntl.sql

   db2start
   db2 connect to $FRNDB
   db2 -fcntl.sql > cntl.out

   medflag=`egrep -v '^C|^-|selected|^$' cntl.out | sed 's/  *//g'`
   
   #delete sample data from the database to avoid unique/referential constraint
   echo "delete from  BASE_ACCESS" > delete.sql
   echo "delete from  BASE_COLLECTIONS" >> delete.sql
   echo "delete from  BASE_LIBRARYSERVER" >> delete.sql
   echo "delete from  BASE_MGTTRANSITION" >> delete.sql
   echo "delete from  BASE_OBJECTS" >> delete.sql
   echo "delete from  BASE_STAGING" >> delete.sql
   echo "delete from  BASE_STGGRPCLASS" >> delete.sql
   echo "delete from  BASE_STGGRPVOLUME" >> delete.sql
   echo "delete from  BASE_STORAGEGROUP" >> delete.sql
   echo "delete from  BASE_STRINGS" >> delete.sql
   echo "delete from  BASE_VOLUMES" >> delete.sql
   echo "delete from  SBTSBTABLES" >> delete.sql
   echo "delete from  BASE_STGCLSDEVMGR" >> delete.sql
   echo "delete from  BASE_DEVMGR" >> delete.sql
   echo "delete from  BASE_MGTCLASS" >> delete.sql
   echo "delete from  BASE_STORAGECLASS" >> delete.sql
   echo "delete from  BASE_OBJECTSERVER" >> delete.sql
   echo "commit" >> delete.sql
   echo "drop table BASE_CNTL" >> delete.sql
   echo " CREATE TABLE BASE_CNTL \\ " >> delete.sql
   echo " ( CTL_CONFIGID              CHAR(16)                         NOT null, \\ " >> delete.sql
   echo "   CTL_CONFIGACTIVE          CHAR                             NOT null, \\ " >> delete.sql
   echo "   CTL_DESCRIPTION           CHAR(80)                         NOT null, \\ " >> delete.sql
   echo "   CTL_PROCESSMAX            SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_LIBTIMEOUT            INTEGER                          NOT null, \\ " >> delete.sql
   echo "   CTL_CLIENTTIMEOUT         INTEGER                          NOT null, \\ " >> delete.sql
   echo "   CTL_PURGERTIMEOUT         INTEGER                          NOT null, \\ " >> delete.sql
   echo "   CTL_MOUNTTIMEOUT          INTEGER                          NOT null, \\ " >> delete.sql
   echo "   CTL_PURGERCYCLE           SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_MIGRATORCYCLE         SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_DESTAGERCYCLE         SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_STAGEBATCHSIZE        SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_MIGRABATCHSIZE        SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_MAXLISTBOXMSGS        SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_MIGSTARTMON           CHAR(4)                          NOT null, \\ " >> delete.sql
   echo "   CTL_MIGMONMINS            SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_MIGSTARTTUE           CHAR(4)                          NOT null, \\ " >> delete.sql
   echo "   CTL_MIGTUESMINS           SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_MIGSTARTWED           CHAR(4)                          NOT null, \\ " >> delete.sql
   echo "   CTL_MIGWEDMINS            SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_MIGSTARTTHURS         CHAR(4)                          NOT null, \\ " >> delete.sql
   echo "   CTL_MIGTHURSMINS          SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_MIGSTARTFRI           CHAR(4)                          NOT null, \\ " >> delete.sql
   echo "   CTL_MIGFRIMINS            SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_MIGSTARTSAT           CHAR(4)                          NOT null, \\ " >> delete.sql
   echo "   CTL_MIGSATMINS            SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   CTL_MIGSTARTSUN           CHAR(4)                          NOT null, \\ " >> delete.sql
   echo "   CTL_MIGSUNMINS            SMALLINT                         NOT null, \\ " >> delete.sql
   echo "   PRIMARY KEY (CTL_CONFIGID))  " >> delete.sql

   echo "alter table base_cntl add CTL_MPURGERENABLE   CHAR(1)     NOT NULL with default  \\ " >  $EXPDIR/alter.sql
   echo "                      add CTL_MPURGERCYCLE    SMALLINT    NOT NULL with default  \\ " >> $EXPDIR/alter.sql
   echo "                      add CTL_MDESTAGRENABLE  CHAR(1)     NOT NULL with default  \\ " >> $EXPDIR/alter.sql
   echo "                      add CTL_MDESTAGRCYCLE   SMALLINT    NOT NULL with default  \\ " >> $EXPDIR/alter.sql
   echo "                      add CTL_MSTAGEBATCHSZE  SMALLINT    NOT NULL with default  \\ " >> $EXPDIR/alter.sql
   echo "                      add CTL_MEDIACONFIG     CHAR(1)     NOT NULL with default     " >> $EXPDIR/alter.sql

   echo "UPDATE BASE_CNTL SET CTL_MPURGERENABLE='N',           \\   " >> $EXPDIR/alter.sql
   echo "                     CTL_MPURGERCYCLE=24,             \\   " >> $EXPDIR/alter.sql
   echo "                     CTL_MDESTAGRENABLE='N',          \\   " >> $EXPDIR/alter.sql
   echo "                     CTL_MDESTAGRCYCLE=24,            \\   " >> $EXPDIR/alter.sql
   echo "                     CTL_MSTAGEBATCHSZE=10,           \\   " >> $EXPDIR/alter.sql
   if [[ $medflag = 'Y' || $medflag = 'y' ]]; then
      echo "                     CTL_MEDIACONFIG='Y'                   " >> $EXPDIR/alter.sql
   else
      echo "                     CTL_MEDIACONFIG='N'                   " >> $EXPDIR/alter.sql
   fi

   echo "REORGCHK ON TABLE ALL " >> $EXPDIR/runstat.sql

   #To set the Buff page to the original value
   buffpage=`cat $EXPDIR/dbcfg.lst |grep BUFFPAGE | awk '{print $7}'`
   echo "update db cfg for $FRNDB using BUFFPAGE $buffpage" > $EXPDIR/upbfpg.sql

  
  for tblnm in `cat $TBLLST`
  do
      if [[ $tblnm = BASEOBJECTS ]]; then
         echo "LOAD FROM $EXPDIR/$tblnm.ixf OF IXF SAVECOUNT 10000 MESSAGES $EXPDIR/$tblnm.msg REPLACE INTO $tblnm" >> $IMPLST
      else
         echo "IMPORT FROM $EXPDIR/$tblnm.ixf OF IXF COMMITCOUNT 10000 MESSAGES $EXPDIR/$tblnm.msg INSERT INTO $tblnm" >> $IMPLST
      fi
      if [[ $? -ne 0 ]]; then
         echo "\nFailed to append $tblnm to $IMPLST"
      fi
  done
  #use existing file obj_exp.cmd to get files needed here
  db2 -fdelete.sql > delete.log
  cnt=`egrep -v "SQL0100W|DB20000I|SQLSTATE=02000|^$" delete.log|wc -l`
  if (( $cnt != 0 )); then
     echo "Error occurred while deleting sample data, see delete.log"
     exit 1
  fi
  rm delete.sql
  cat /dev/null > $EXPDIR/imp.log
  db2 -f$IMPLST -r$EXPDIR/imp.log
  if [[ $? -lt 3 ]]; then
     db2 -f$EXPDIR/alter.sql > alter.log
     if [[ $? -eq 0 ]]; then
        rm $EXPDIR/alter.sql
        echo "Import data to $FRNDB has been completed, update media info ...."
        #7228 begin
        echo "select max(vol_volumeid+1) from base_volumes" > volume.sql
        echo "select max(dev_devmgrid+1) from base_devmgr" > devmgr.sql
        echo "select max(stc_stgclassid+1) from base_storageclass" > stgcls.sql
        echo "select max(stg_stggroupid+1) from base_storagegroup" > stggrp.sql
        echo "select max(mgc_mgtclassid+1) from base_mgtclass" > mgtcls.sql
        echo "select max(col_collid+1) from base_collections" > collid.sql

        db2 -fvolume.sql > volume.out
        db2 -fdevmgr.sql > devmgr.out
        db2 -fstgcls.sql > stgcls.out
        db2 -fstggrp.sql > stggrp.out
        db2 -fmgtcls.sql > mgtcls.out
        db2 -fcollid.sql > collid.out

        if [[ $? -eq 0 ]]; then

           devmgrid=`egrep -v '^1|^---|selected|^$' devmgr.out| sed "s/^  *//g;s/  *$//g"`
           stgclsid=`egrep -v '^1|^---|selected|^$' stgcls.out| sed "s/^  *//g;s/  *$//g"`
           stggrpid=`egrep -v '^1|^---|selected|^$' stggrp.out| sed "s/^  *//g;s/  *$//g"`
           mgtclsid=`egrep -v '^1|^---|selected|^$' mgtcls.out| sed "s/^  *//g;s/  *$//g"`
           collid=`egrep -v '^1|^---|selected|^$' collid.out| sed "s/^  *//g;s/  *$//g"`
           volumeid=`egrep -v '^1|^---|selected|^$' volume.out| sed "s/^  *//g;s/  *$//g"`

           if [[ $medflag = 'Y' || $medflag = 'y' ]]; then
              echo "INSERT INTO BASE_DEVMGR VALUES ($devmgrid,'FRNXMADM','00000004','Y','IBM MEDIA ARCHIVER DEVICE MANAGER','')" >> mediainfo.sql
           else
              echo "INSERT INTO BASE_DEVMGR VALUES ($devmgrid,'FRNXMADM','00000004','N','IBM MEDIA ARCHIVER DEVICE MANAGER','')" > mediainfo.sql
           fi
           echo "INSERT INTO BASE_STORAGECLASS VALUES ($stgclsid,'MEDIASTC',1,0,'','','',0)" >> mediainfo.sql
           echo "INSERT INTO BASE_STORAGEGROUP VALUES ($stggrpid,'MEDIASTG')" >> mediainfo.sql
           echo "INSERT INTO BASE_MGTCLASS VALUES ($mgtclsid,'MEDIAMGC',0,0,0)" >> mediainfo.sql
           echo "INSERT INTO BASE_MGTTRANSITION VALUES($mgtclsid,1,$stgclsid,1,30,0,12)" >> mediainfo.sql
           echo "INSERT INTO BASE_COLLECTIONS VALUES ($collid,'Media.Collectn.Archive',$stggrpid,$mgtclsid)" >> mediainfo.sql
           collid=$(($collid + 1))
           echo "INSERT INTO BASE_COLLECTIONS VALUES ($collid,'Media.Collectn.NoArchiv',$stggrpid,$mgtclsid)" >> mediainfo.sql
           echo "INSERT INTO BASE_STGCLSDEVMGR VALUES ($stgclsid,$devmgrid)" >> mediainfo.sql
           echo "INSERT INTO BASE_STGGRPCLASS VALUES ($stggrpid,$stgclsid)" >> mediainfo.sql
           echo "INSERT INTO BASE_VOLUMES VALUES ($volumeid,'MSARCHIV','MSARCHIV','MSARCHIV',$devmgrid,$stgclsid,0,0,0,181,'A',1,CURRENT DATE, 'Offline')" >> mediainfo.sql
           echo "INSERT INTO BASE_STGGRPVOLUME VALUES ($stggrpid, $volumeid)" >> mediainfo.sql
           if [[ $? -eq 0 ]]; then
              db2 -fmediainfo.sql > media.log
              if [[ $? -eq 0 ]]; then
                 echo "Finish adding media info to database tables"
                 echo "see $EXPDIR/imp.log for data import information "
                 rm *.sql *.out
              else
                 echo "Error encountered while adding media info to database tables"
                 echo "check $EXPDIR/imp.log for data import information "
                 echo "see media.log for media error message"
              fi

              echo "UPDATE SBTSBTABLES SET TABLENAME=SUBSTR(TABLENAME,6) WHERE TABLENAME LIKE 'ROOT.%'" > update.sql
              db2 -fupdate.sql >> $EXPDIR/imp.log

              if [[ $? -ne 0 ]]; then
                  echo "failed to complete UPDATING SBTSBTABLES, see frnxmilt.msg for
detail"
              fi

              db2 -f$EXPDIR/runstat.sql > $EXPDIR/runstat.log
              if [[ $? -ne 0 ]]; then
                  echo "Error: Updating table statistics. Check $EXPDIR/runstat.log"
                  echo "for more detail                                            "
              fi
              #restore buffpage size to the previous version db value
              echo " "
              echo "Updating BuffPage size ...."
              db2 -f$EXPDIR/upbfpg.sql -z$EXPDIR/upbfpg.log > /dev/null 2>&1

              rm $EXPDIR/upbfpg.sql > /dev/null 2>&1


	      #Bind the database
      		if [[ -a /usr/lpp/frn/bin/frnbind.obj ]]; then
         	   echo "The Database is being bound to the plan ...."
         	   /usr/lpp/frn/bin/frnbind.obj   > /dev/null 2>&1
      		else
                   echo "ERROR: Cannot find frnbind.obj in /usr/lpp/frn/bin"
                 fi



           else
              echo "Error encountered while building mediainfo.sql file"
              echo "check $EXPDIR/imp.log for data import information "
              echo "see mediainfo.sql for detail"
           fi
        else
           echo "Error encountered when getting max_id from database tables"
           echo "check $EXPDIR/imp.log for data import information "
           echo "see *.out files for media info"
        fi
        #7228 end
     else
        echo "Error occurred while alter BASE_CNTL table"
        exit 1
     fi
  else
     echo "Error occurred while importing data, see $EXPDIR/imp.log"
     echo "also, check $EXPDIR/<TABLENAME>.msg for error"
  fi
else
   echo "\nThe Migration program can not proceed without $EXPDIR."
   exit 1
fi
