#!/bin/ksh
#***********************************************************************
# Digital Library Version 2 - 5765-C86.                                *
# VisualInfo Version 2 Release 3.0 - 5697-250.                         *
# (C) Copyright IBM Corp. 1994,1997.                                   *
# All Rights Reserved.                                                 *
#                                                                      *
# US Government Users Restricted Rights                                *
# Use, duplication or disclosure restricted by GSA ADP Schedule        *
# Contract with IBM Corp.                                              *
# Licensed Materials - Property of IBM                                 *
#***********************************************************************
#***********************************************************************
# Program name  : frnxmiol.oracle.sh                                   *
#                                                                      *
# Description   : Object server database migration                     *
#                      from AIX DB2 DL V1 to AIX ORACLE DL V2          *
#***********************************************************************
#export FRNROOT=.

# Display copyright statement
cat copyright

# Setup message variables
#. ./frnxcosm.sh

user=`whoami`
if [[ $user != "oracle" ]]; then
   echo "Only the user oracle may perform database migration, exit."
   exit 1
fi # end of if current user is not oracle

#prompt for oracle database name and password for "oracle"
LOG=/tmp/migrate.log
cat /dev/null > $LOG
echo "\nEnter ORACLE database name: \c"
      #dspmsg $MSG_MSGFILE $MSG_ENTERORACLEDBNAME "$MSG_MSGNOTFOUND"
read dbname
if [[ -z "$dbname" ]]; then
   echo "\nCan not proceed without database name, exit"
   #dspmsg $MSG_MSGFILE $MSG_NODBNAME "$MSG_MSGNOTFOUND"
   exit 1
else
   typeset -u dbname
   export ORADB=$dbname
   export ORACLE_SID=$dbname
fi
echo "\nEnter the database userid: "
#dspmsg $MSG_MSGFILE $MSG_ENTERDBUSERID "$MSG_MSGNOTFOUND"
read answer
if [[ -z "$answer" ]]; then
   echo "\nCan not proceed without userid, exit"
   #dspmsg $MSG_MSGFILE $MSG_NOUSERID "$MSG_MSGNOTFOUND"
   exit 1
else
   export ORAID=$answer
fi
echo "\nEnter the database password: "
#dspmsg $MSG_MSGFILE $MSG_ENTERDBPASSWORD "$MSG_MSGNOTFOUND"
stty -echo
read answer
stty echo
echo 
if [[ -z "$answer" ]]; then
   echo "\nCan not proceed without password, exit"
   #dspmsg $MSG_MSGFILE $MSG_NOPASSWORD "$MSG_MSGNOTFOUND"
   exit 1
else
   export ORAPWD=$answer
fi

#begin d7228 select ctl_mediaconfig from base_cntl for later use
echo "select ctl_mediaconfig from base_cntl;" > medflag.sql
svrmgrl<<- EOF
connect $ORAID/$ORAPWD;
spool medflag.out
@medflag.sql
spool off;
exit;
EOF

medflag=`egrep -v '^C|^-|selected|^$' medflag.out`
#end d7228

#delete sample data from database  

echo "delete from  BASE_ACCESS;" > delete.sql
echo "delete from  BASE_CNTL;" >> delete.sql
echo "delete from  BASE_COLLECTIONS;" >> delete.sql
echo "delete from  BASE_LIBRARYSERVER;" >> delete.sql
echo "delete from  BASE_MGTTRANSITION;" >> delete.sql
echo "delete from  BASE_OBJECTS;" >> delete.sql
echo "delete from  BASE_STAGING;" >> delete.sql
echo "delete from  BASE_STGGRPCLASS;" >> delete.sql
echo "delete from  BASE_STGGRPVOLUME;" >> delete.sql
echo "delete from  BASE_STORAGEGROUP;" >> delete.sql
echo "delete from  BASE_STRINGS;" >> delete.sql
echo "delete from  BASE_VOLUMES;" >> delete.sql
echo "delete from  SBTSBTABLES;" >> delete.sql
echo "delete from  BASE_STGCLSDEVMGR;" >> delete.sql
echo "delete from  BASE_DEVMGR;" >> delete.sql
echo "delete from  BASE_MGTCLASS;" >> delete.sql
echo "delete from  BASE_STORAGECLASS;" >> delete.sql
echo "delete from  BASE_OBJECTSERVER;" >> delete.sql
echo "commit;" >> delete.sql

svrmgrl<<- EOF
connect $ORAID/$ORAPWD;
spool delete.log
@delete.sql
spool off;
exit;
EOF

cnt=`grep ORA- delete.log|wc -l`
if (( $cnt != 0 )); then
   echo "Error occurred while deleting sample data, see delete.log"
   exit 1
fi

echo "\nLoad data into database tables, please wait ... " | tee -a $LOG
#dspmsg $MSG_MSGFILE $MSG_LOADINGDATA "$MSG_MSGNOTFOUND" \ | tee -a $LOG
. exp/load.sql $ORAID $ORAPWD 
err=$?
if [[ $err -eq 0 ]]; then #create tables successfully
   #begin d7228 add media info into Object server tables after database migration
   #echo "\nLoad data into $ORADB successfully. " | tee -a $LOG
   #dspmsg $MSG_MSGFILE $MSG_DATALOADOK "$MSG_MSGNOTFOUND" "$ORADB" \ | tee -a $LOG
   echo "\nLoad data into $ORADB successfully, adding media info .... " | tee -a $LOG
   echo "spool  cntl.out" > getmax.sql
   echo "select ctl_mediaconfig from base_cntl;" >> getmax.sql
   echo "spool off" >> getmax.sql
   echo "spool volume.out" >> getmax.sql
   echo "select max(vol_volumeid+1) from base_volumes;" >> getmax.sql
   echo "spool off" >> getmax.sql
   echo "spool devmgr.out" >> getmax.sql
   echo "select max(dev_devmgrid+1) from base_devmgr;" >> getmax.sql
   echo "spool off" >> getmax.sql
   echo "spool stgcls.out" >> getmax.sql
   echo "select max(stc_stgclassid+1) from base_storageclass;" >> getmax.sql
   echo "spool off" >> getmax.sql
   echo "spool stggrp.out" >> getmax.sql
   echo "select max(stg_stggroupid+1) from base_storagegroup;" >> getmax.sql
   echo "spool off" >> getmax.sql
   echo "spool mgtcls.out" >> getmax.sql
   echo "select max(mgc_mgtclassid+1) from base_mgtclass;" >> getmax.sql
   echo "spool off" >> getmax.sql
   echo "spool collid.out" >> getmax.sql
   echo "select max(col_collid+1) from base_collections;" >> getmax.sql
   echo "spool off" >> getmax.sql

svrmgrl<<- EOF
connect $ORAID/$ORAPWD;
@getmax.sql
exit;
EOF

   if [[ $? -eq 0 ]]; then
      devmgrid=`egrep -v 'MAX|^---|selected' devmgr.out| sed "s/^  *//g"`
      stgclsid=`egrep -v 'MAX|^---|selected' stgcls.out| sed "s/^  *//g"`
      stggrpid=`egrep -v 'MAX|^---|selected' stggrp.out| sed "s/^  *//g"`
      mgtclsid=`egrep -v 'MAX|^---|selected' mgtcls.out| sed "s/^  *//g"`
      collid=`egrep -v 'MAX|^---|selected' collid.out| sed "s/^  *//g"`
      volumeid=`egrep -v 'MAX|^---|selected' volume.out| sed "s/^  *//g"`
      enable=`egrep -v 'CTL|^----|selected' cntl.out`
      echo "spool media.log" > mediainfo.sql
      if [[ $medflag = 'Y' || $medflag = 'y' ]]; then
         echo "UPDATE BASE_CNTL set CTL_MEDIACONFIG='Y';" >> mediainfo.sql
         echo "INSERT INTO BASE_DEVMGR VALUES ($devmgrid,'FRNXMADM','00000004','Y','IBM MEDIA ARCHIVER DEVICE MANAGER','');" >> mediainfo.sql
      else
         echo "INSERT INTO BASE_DEVMGR VALUES ($devmgrid,'FRNXMADM','00000004','N','IBM MEDIA ARCHIVER DEVICE MANAGER','');" >> mediainfo.sql
      fi
      echo "INSERT INTO BASE_STORAGECLASS VALUES ($stgclsid,'MEDIASTC',1,0,'','','',0);" >> mediainfo.sql
      echo "INSERT INTO BASE_STORAGEGROUP VALUES ($stggrpid,'MEDIASTG');" >> mediainfo.sql
      echo "INSERT INTO BASE_MGTCLASS VALUES ($mgtclsid,'MEDIAMGC',0,0,0);" >> mediainfo.sql
      echo "INSERT INTO BASE_MGTTRANSITION VALUES($mgtclsid,1,$stgclsid,1,30,0,12);" >> mediainfo.sql
      echo "INSERT INTO BASE_COLLECTIONS VALUES ($collid,'Media.Collectn.Archive',$stggrpid,$mgtclsid);" >> mediainfo.sql
      collid=$(($collid + 1))
      echo "INSERT INTO BASE_COLLECTIONS VALUES ($collid,'Media.Collectn.NoArchiv',$stggrpid,$mgtclsid);" >> mediainfo.sql
      echo "INSERT INTO BASE_STGCLSDEVMGR VALUES ($stgclsid,$devmgrid);" >> mediainfo.sql
      echo "INSERT INTO BASE_STGGRPCLASS VALUES ($stggrpid,$stgclsid);" >> mediainfo.sql
      echo "INSERT INTO BASE_VOLUMES VALUES ($volumeid,'MSARCHIV','MSARCHIV','MSARCHIV',$devmgrid,$stgclsid,0,0,0,181,'A',1,TO_DATE(SYSDATE, 'DD-MON-YYYY'), 'Offline');" >> mediainfo.sql
      echo "INSERT INTO BASE_STGGRPVOLUME VALUES ($stggrpid, $volumeid);" >> mediainfo.sql
      echo "spool off" >> mediainfo.sql
      if [[ $? -eq 0 ]]; then
svrmgrl<<- EOF
connect $ORAID/$ORAPWD;
@mediainfo.sql
exit;
EOF
         if [[ $? -eq 0 ]]; then
            echo "\nFinish adding media info to database tables"
            echo "\nMigration has been completed successfully!"
            rm *.sql *.out
         else
            echo "Error encountered while adding media info to database tables"
            echo "see media.log for detail, however, old data has been loaded into new database successfully."
         fi
      else
         echo "Error encountered while building mediainfo.sql file"
         echo "however, old data has been loaded into new database successfully."  
      fi 
   else
      echo "Error encountered when getting max_id from database tables, see *.out"
      echo "however, old data has been loaded into new database successfully."  
   fi
#end d7228
else
   echo "\nLoad data failed.  Return code=$err" | tee -a $LOG
   #dspmsg $MSG_MSGFILE $MSG_TBLLOADERROR "$MSG_MSGNOTFOUND" "$err" \ | tee -a $LOG
fi
echo "\nSee exp/*.log for Oracle sqlloader info"

