#!/bin/ksh
#***********************************************************************
# Digital Library Version 2 - 5765-C86.                                *
# VisualInfo Version 2 Release 3.0 - 5697-250.                         *
# (C) Copyright IBM Corp. 1994,1997.                                   *
# All Rights Reserved.                                                 *
#                                                                      *
# US Government Users Restricted Rights                                *
# Use, duplication or disclosure restricted by GSA ADP Schedule        *
# Contract with IBM Corp.                                              *
# Licensed Materials - Property of IBM                                 *
#***********************************************************************
#!/bin/ksh
#***********************************************************************
#                                                                      *
# Program name  : frnxinlc.ora.sh                                      *
#                                                                      *
# Description   : Database creation prep to be run by database         *
#                 administrator.                                       *
#                                                                      *
#***********************************************************************

# FRNROOT should already be set

# Setup message variables
. $FRNROOT/frnxcosm.sh

# Set up log file
DBCRTLOGFILE=/tmp/installdb.log
cat /dev/null > $DBCRTLOGFILE
DBCRTLOG=$DBCRTLOGFILE  > /dev/null 2>&1

# Ensure that only the oracle user performs creation and setup of database
user=`whoami`
if [[ $user != "oracle" ]]; then
   # echo "\nThe user $user may not perform this installation function."
   # echo "  Only the oracle user may perform creation and set-up of the "
   # echo "  database.  Database creation terminated abnormally. \n"
   dspmsg $MSG_MSGFILE $MSG_USERCANNOTINSTALL "$MSG_MSGNOTFOUND" "$user" \
        | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_ORACLEMUSTCREATEDB "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_DBCREATEABEND "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   exit 1
fi # end of if current user is not oracle

# Check ORACLE_HOME
if [[ "$ORACLE_HOME" = "" ]]; then
   # echo "\nPlease set up ORACLE_HOME. "
   dspmsg $MSG_MSGFILE $MSG_ORACLEHOMENOTSET "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   exit 1
fi

# Get a valid database name from the installer
if [[ "$SEL" -ne 3 ]]; then
VALIDDB=0; # reset edit switch
getinput=1
 if [[ "$1" != "" ]]; then
    getinput=0
 fi # endof if database name was entered on command line
 until [[ "$VALIDDB" = 1 ]]; do
    if [[ getinput -ne 0 ]]; then
      # Determine the name of the database to create
      # echo "\nEnter the name of the database you want to create,"
      # echo "  or press enter to choose the default of LIBSRVRX. : \c"
      dspmsg $MSG_MSGFILE $MSG_ENTERDBNAME "$MSG_MSGNOTFOUND" "LIBSRVRX" \
        | tee -a $DBCRTLOG
      read dbname
      typeset -u dbname
      echo $dbname >> $DBCRTLOG
      if [[ -z "$dbname"  ]]; then  # is string missing?
         VALIDDB=1
         # use default server name
         export FRNLDBNAME=LIBSRVRX
         export ORACLE_SID=LIBSRVRX
      else
         # installer entered server name
         # check to make sure length does not exceed 8 characters+newline
         if
            echo "$dbname" | wc -c | awk '{ if ($1 > 9)
              {
                  exit(1)
              }
              else {
                  exit(0)
                   }
              }'
         then
            VALIDDB=1
            typeset -u dbname
            export FRNLDBNAME=$dbname
            export ORACLE_SID=$dbname
         else
            # echo "\nDatabase name cannot exceed 8 characters \n"
            dspmsg $MSG_MSGFILE $MSG_DBNAMETOOLONG "$MSG_MSGNOTFOUND" \
                  "$dbname" | tee -a $DBCRTLOG
            VALIDDB=1
            exit 1
         fi  # end if echo to determine db name length
      fi     # end of if dbname is missing
   else

      # database name was entered on command line
      # check to make sure length does not exceed 8 characters+newline
      if
         echo "$1" | wc -c | awk '{ if ($1 > 9)
         {
            exit(1)
         }
         else
         {
            VALIDDB=1
            exit(0)
         }
      }'
      then
         dbname=$1
         typeset -u dbname
         export FRNLDBNAME=$dbname
         export ORACLE_SID=$dbname
         VALIDDB=1
      else
         # echo "\nDatabase name cannot exceed 8 characters \n"
         dspmsg $MSG_MSGFILE $MSG_DBNAMETOOLONG "$MSG_MSGNOTFOUND" "$dbname" \
                | tee -a $DBCRTLOG
         VALIDDB=1
         exit 1
      fi # end of if echo to determine database name length
   fi # end of if database name was not entered on command line
done  # end of until do loop
fi

# Check to see if there is an instance with this ORACLE_SID
# echo "\nChecking the existence of $FRNLDBNAME, please wait ..."
dspmsg $MSG_MSGFILE $MSG_DBEXISTCHECK "$MSG_MSGNOTFOUND" "$FRNLDBNAME" \
        | tee -a $DBCRTLOG
oracle_output=`svrmgrl<<- EOF
connect internal;
startup;
select username from user_users;
exit;
EOF`

result=`echo $oracle_output | grep ORA- | wc -l`

started=`echo $oracle_output | grep ORA-01081 | wc -l`

if (( started == 1 || ( started == 0 && result == 0 ))); then
   oracle_output=`svrmgrl<<- EOF
   connect internal;
   shutdown abort;
   exit;
  EOF`
fi

# Get the userid for create database tables
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
   # echo "\nPlease enter the userid for Library Server database"
   # echo "  $FRNLDBNAME who will be the owner of database tables"
   # echo "  or press enter to choose the default, dllssrvr: \c\n"
   dspmsg $MSG_MSGFILE $MSG_GETDBID "$MSG_MSGNOTFOUND" "$FRNLDBNAME" \
        | tee -a $DBCRTLOG
   read answer
   echo $answer >> $DBCRTLOG
   if [[ -z "$answer" ]]; then    # is string missing?
      # use default database description
      FRNUSERID=dllssrvr
      export FRNUSERID
      VALIDDB=1
   else
      # check to make sure length does not exceed 8 characters+newline
      if
         echo "$answer" | wc -c | awk '{ if ($1 > 9)
            {
               exit(1)
            }
         else {
               exit(0)
            }
         }'
      then
         VALIDDB=1
         FRNUSERID=$answer
         export FRNUSERID
      else
         # echo "\nDatabase owner id $answer cannot exceed 8 characters \n"
         dspmsg $MSG_MSGFILE $MSG_DBOWNERTOOLONG "$MSG_MSGNOTFOUND" \
                "$answer" | tee -a $DBCRTLOG
      fi  #
   fi # end of string missing
done

# Get the password for $FRNUSERID
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
   # echo "\nPlease enter the password for userid $FRNUSERID "
   # echo "  or press enter to choose the default, oracle. : \c\n"
   dspmsg $MSG_MSGFILE $MSG_GETPASSWD "$MSG_MSGNOTFOUND" "$FRNUSERID" \
        | tee -a $DBCRTLOG
   stty -echo
   read answer
   stty echo
   echo | tee -a $DBCRTLOG
   if [[ -z "$answer" ]]; then    # is string missing?
      # use default database description
      FRNPASSWD=oracle
      export FRNPASSWD
      VALIDDB=1
   else
      # check to make sure length does not exceed 8 characters+newline
      if
         echo "$answer" | wc -c | awk '{ if ($1 > 9)
            {
               exit(1)
            }
         else {
               exit(0)
            }
         }'
      then
         VALIDDB=1
         FRNPASSWD=$answer
         export FRNPASSWD
      else
         # echo "\nPassword cannot exceed 8 characters \n"
         dspmsg $MSG_MSGFILE $MSG_PASSWORDTOOLONG "$MSG_MSGNOTFOUND" \
                | tee -a $DBCRTLOG
      fi  #
   fi # end of missing string
done

# Check if database is local
# echo
# echo "\nIs the library server image installed"
# echo "  on this machine?"
# echo "  If yes, type Y. "
# echo "  If no, type any other key for no. : \c"
dspmsg $MSG_MSGFILE $MSG_LSIMAGEINSTALLED "$MSG_MSGNOTFOUND" \
                | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_ENTERYESORNO "$MSG_MSGNOTFOUND" "$DB2INSTANCE" \
                | tee -a $DBCRTLOG
read answer
echo $answer >> $DBCRTLOG
if [[    "$answer" != $NLS_YES1
      && "$answer" != $NLS_YES2
      && "$answer" != $NLS_YES3
      && "$answer" != $NLS_YES4 ]]; then
   export LOCAL_DB=REMOTE
else
   export LOCAL_DB=LOCAL
fi # end of if answer is yes

# Find database path
VARFILE=$ORACLE_HOME/dbs/$FRNLDBNAME.var
if [[ -s $VARFILE ]]; then
   FRNDB_BASE=`grep PATH $VARFILE|cut -d= -f2`
   if [[ -d $FRNDB_BASE ]]; then
      export FRNDB_BASE
   else
      # echo "\nDatabase path $FRNDB_BASE does not exist, "
      # echo "  file frncrt.dbfile.lib need to be executed first.  Exit."
      dspmsg $MSG_MSGFILE $MSG_NODBPATH "$MSG_MSGNOTFOUND" "$FRNDB_BASE" \
                | tee -a $DBCRTLOG
      exit 1
   fi
else
   # echo "\n$VARFILE does not exist, file frncrt.dbfile.lib need to be"
   # echo "  executed first.  Exit."
   dspmsg $MSG_MSGFILE $MSG_NOVARFILE "$MSG_MSGNOTFOUND" "$VARFILE" \
                | tee -a $DBCRTLOG
   exit 1
fi

# Check if database exists
if [[ -a $FRNDB_BASE/syst$FRNLDBNAME.dbf || -a $FRNDB_BASE/log1$FRNLDBNAME.dbf || -a $FRNDB_BASE/ctr101.ctl ]];
then
   # echo "\nDatabase already exists.  Would you like to delete the"
   # echo "  old one - path $FRNDB_BASE? "
   # echo "  If yes, type Y. If no, type any other key for no to exit: \c"
   dspmsg $MSG_MSGFILE $MSG_DBEXISTS "$MSG_MSGNOTFOUND" "$FRNDB_BASE" \
        | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_ENTERYESORNO "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   read answer
   echo $answer >> $DBCRTLOG
   if [[    "$answer" != $NLS_YES1
         && "$answer" != $NLS_YES2
         && "$answer" != $NLS_YES3
         && "$answer" != $NLS_YES4 ]]; then
      # echo "\nDatabase creation terminated normally. \n"
      dspmsg $MSG_MSGFILE $MSG_DBCREATETERMNORM "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
      exit 0 # dont overwrite old
   else #delete existing database
      export DBEXIST=1
   fi # end if answer is yes
fi

# Create dump log directory
DUMP_LOG=$FRNDB_BASE/log
if [[ -d $DUMP_LOG ]]; then
   # Dump log $FRNDB_BASE/log directory already exists
   dspmsg $MSG_MSGFILE $MSG_DIRECTORYEXISTS "$MSG_MSGNOTFOUND" \
          "$FRNDB_BASE/log" | tee -a $DBCRTLOG
else
   mkdir $DUMP_LOG > /dev/null 2>&1
   if [[ $? -eq 0 ]]; then
      # Dump log directory does not exist
      dspmsg $MSG_MSGFILE $MSG_DIRDOESNOTEXISTS "$MSG_MSGNOTFOUND" \
             "$FRNDB_BASE/log" | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_DIRCREATED "$MSG_MSGNOTFOUND" \
             "$FRNDB_BASE/log" | tee -a $DBCRTLOG
      export DUMP_LOG
   else
      # Create dump log directory failed
      dspmsg $MSG_MSGFILE $MSG_DIRCREATEFAILED "$MSG_MSGNOTFOUND" \
             "$FRNDB_BASE/log" | tee -a $DBCRTLOG
      exit 1
   fi
fi

# Get database description
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
     # Determine the database descripton
     # echo "\nEnter the database description (1-30 characters),"
     # echo "  or press enter to choose default of"
     # echo "  'Library Server Database' : \c"
     dspmsg $MSG_MSGFILE $MSG_ENTERLSDBDESC "$MSG_MSGNOTFOUND" \
                | tee -a $DBCRTLOG
     read answer
     echo $answer >> $DBCRTLOG
     if [[ -z "$answer"  ]]; then  # is string missing?
        VALIDDB=1
        # use default server name
        FRNLDBCOMMENT="$NLS_LSDBDESC_DEFAULT"
        export FRNLDBCOMMENT
     else
        # setup for user entered server description
        VALIDDB=1
        FRNLDBCOMMENT="$answer"
        export FRNLDBCOMMENT
     fi  # end of if dbname is missing
done  # end of until loop

# Get Object Server name
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
     # Determine the name of the Object server database
     # echo "\nEnter the name of the initial Object Server database"
     # echo "  you want to reference, or press enter to choose "
     # echo "  the default of OBJSRVRX. : \c"
     dspmsg $MSG_MSGFILE $MSG_ENTEROBJSERVERDB "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
     read objname
     typeset -u objname
     echo $objname >> $DBCRTLOG
     if [[ -z "$objname" ]]; then    # is string missing?
        VALIDDB=1
        # use default object server name
        FRNODBNAME=OBJSRVRX
        export FRNODBNAME
     else
        # installer entered object server name
        # check to make sure length does not exceed 8 characters+newline
        if
           echo "$objname" | wc -c | awk '{ if ($1 > 9)
           {
              exit(1)
           }
        else
           {
              exit(0)
           }
        }'
        then
           VALIDDB=1
           FRNODBNAME=$objname
           export FRNODBNAME
        else
           # echo "\nDatabase name $objname cannot exceed 8 characters. "
           dspmsg $MSG_MSGFILE $MSG_DBNAMETOOLONG "$MSG_MSGNOTFOUND" \
                "$objname" | tee -a $DBCRTLOG
        fi # end if echo to determine database name length
     fi # end of if database name is missing
done # end of until do loop

# Get item name length
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
   # Determine the item name length
   # Enter the item name length(25-50)
   dspmsg $MSG_MSGFILE $MSG_ENTERITEMNAMELENGTH "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   read answer
   echo $answer >> $DBCRTLOG
   if [[ -z "$answer" ]]; then    # is string missing?
      VALIDDB=1
      # use default item name length
      FRNLDBLABELL=50
      export FRNLDBLABELL
   else
      # installer entered item name length
      # check to make sure item name length between 25 and 50
      if [[ "$answer" -gt 24 && "$answer" -lt 51 ]]; then
         VALIDDB=1
         FRNLDBLABELL=$answer
         export FRNLDBLABELL
      else
         # Item name length must be between 25-50
         dspmsg $MSG_MSGFILE $MSG_BADITEMNAMELENGTH "$MSG_MSGNOTFOUND" \
                | tee -a $DBCRTLOG
      fi # end of if item name length within range
   fi # end of if item name length is missing
done # end of until do loop

# Get value field length
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
   # determine the value field length
   # Enter the value field length(1-100)
   dspmsg $MSG_MSGFILE $MSG_ENTERVALUEFIELDLENGTH "$MSG_MSGNOTFOUND" \
          | tee -a $DBCRTLOG
   read answer
   echo $answer >> $DBCRTLOG
   if [[ -z "$answer" ]]; then    # is string missing?
      VALIDDB=1
      # use default value field length
      FRNLDBVALUEL=100
      export FRNLDBVALUEL
   else
      # setup for user entered value field length
      # check to make sure value field length between 1 and 100
      if [[ "$answer" -gt 0 && "$answer" -lt 101 ]]; then
         VALIDDB=1
         FRNLDBVALUEL=$answer
         export FRNLDBVALUEL
      else
        # Value field length must be between 1-100.
         dspmsg $MSG_MSGFILE $MSG_BADVALUEFIELDLENGTH "$MSG_MSGNOTFOUND" \
                | tee -a $DBCRTLOG
      fi # end of if value field length within range
   fi # end of if value field length is missing
done # end of until do loop

# Get name field length
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
   # determine the name field length
   # Enter the name field length(25-80)"
   dspmsg $MSG_MSGFILE $MSG_ENTERNAMEFIELDLENGTH "$MSG_MSGNOTFOUND" \
          | tee -a $DBCRTLOG
   read answer
   echo $answer >> $DBCRTLOG
   if [[ -z "$answer" ]]; then    # is string missing?
      VALIDDB=1
      # use default name field length
      FRNLDBNAMEL=80
      export FRNLDBNAMEL
   else
      # installer entered name field length
      # check to make sure name field length between 25 and 80
      if [[ "$answer" -gt 24 && "$answer" -lt 81 ]]; then
         VALIDDB=1
         FRNLDBNAMEL=$answer
         export FRNLDBNAMEL
      else
         # Name field length must be between 25-80
         dspmsg $MSG_MSGFILE $MSG_BADNAMEFIELDLENGTH "$MSG_MSGNOTFOUND" \
                | tee -a $DBCRTLOG
      fi # end of if name field length within range
   fi # end of if name field length is missing
done # end of until do loop

# Get directory field length
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
   # determine the directory field length
   # Enter the directory field length(1-120)
   dspmsg $MSG_MSGFILE $MSG_ENTERDIRFIELDLENGTH "$MSG_MSGNOTFOUND" \
          | tee -a $DBCRTLOG
   read answer
   echo $answer >> $DBCRTLOG
   if [[ -z "$answer" ]]; then    # is string missing?
      VALIDDB=1
      # use default directory field length
      FRNLDBDIRL=120
      export FRNLDBDIRL
   else
      # installer entered directory field length
      # check to make sure directory field length between 1 and 120
      if [[ "$answer" -gt 1 && "$answer" -lt 121 ]]; then
         VALIDDB=1
         FRNLDBDIRL=$answer
         export FRNLDBDIRL
      else
         # Directory field length must be between 1-120.
         dspmsg $MSG_MSGFILE $MSG_BADDIRFIELDLENGTH "$MSG_MSGNOTFOUND" \
                | tee -a $DBCRTLOG
      fi # end of if directory field length within range
   fi # end of if directory field length is missing
done # end of until do loop

# Locate config.ora file
DBSDIR=$ORACLE_HOME/dbs
CONFIGORA=`grep CONFIGORA $VARFILE|cut -d= -f2`
if [[ -s $CONFIGORA ]]; then
   export CONFIGORA
else
   # $CONFIGORA does not exist
   dspmsg $MSG_MSGFILE $MSG_PATHNOTTHERE "$MSG_MSGNOTFOUND" "$CONFIGORA" \
          | tee -a $DBCRTLOG
   # Run create.dbfile to create $CONFIGORA
   dspmsg $MSG_MSGFILE $MSG_EXECUTEDBFILE "$MSG_MSGNOTFOUND" \
          | tee -a $DBCRTLOG
   exit 1
fi

# Locate init.ora file
INITORA=`grep "INITORA=" $VARFILE|cut -d= -f2`
if [[ -s $INITORA ]]; then
   export INITORA
   INITORA1=$DBSDIR/init$FRNLDBNAME.ora
   if [[ -s $INITORA1 ]]; then
      export INITORA1
   else
      # $INITORA1 does not exist
      dspmsg $MSG_MSGFILE $MSG_PATHNOTTHERE "$MSG_MSGNOTFOUND" "$INITORA1" \
             | tee -a $DBCRTLOG
      # Run create.dbfile to create $INITORA1
      dspmsg $MSG_MSGFILE $MSG_EXECUTEDBFILE "$MSG_MSGNOTFOUND" \
             | tee -a $DBCRTLOG
      exit 1
   fi
else
   # $INITORA does not exist
   dspmsg $MSG_MSGFILE $MSG_PATHNOTTHERE "$MSG_MSGNOTFOUND" "$INITORA" \
          | tee -a $DBCRTLOG
   # Run create.dbfile to create $INITORA1
   dspmsg $MSG_MSGFILE $MSG_EXECUTEDBFILE "$MSG_MSGNOTFOUND" \
          | tee -a $DBCRTLOG
   exit 1
fi

# Display database creation values
dspmsg $MSG_MSGFILE $MSG_DBCREATEVALUES "$MSG_MSGNOTFOUND" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_ORACLESID "$MSG_MSGNOTFOUND" "$ORACLE_SID" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_DBPATH "$MSG_MSGNOTFOUND" "$FRNDB_BASE" \
       | tee -a $DBCRTLOG
if [[ "$CREATE_BACKUP" = 1 ]]; then
dspmsg $MSG_MSGFILE $MSG_BACKUPPATH "$MSG_MSGNOTFOUND" "$FRNDB_BACKUP_BASE" \
       | tee -a $DBCRTLOG
fi
dspmsg $MSG_MSGFILE $MSG_DUMPLOGPATH "$MSG_MSGNOTFOUND" "$DUMP_LOG" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_LIBSERVERNAME "$MSG_MSGNOTFOUND" "$FRNLDBNAME" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_LIBSERVERDESC "$MSG_MSGNOTFOUND" "$FRNLDBCOMMENT" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_OBJSERVERNAME "$MSG_MSGNOTFOUND" "$FRNODBNAME" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_ITEMNAMELENGTH   "$MSG_MSGNOTFOUND" "$FRNLDBLABELL" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_VALUEFIELDLENGTH "$MSG_MSGNOTFOUND" "$FRNLDBVALUEL" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_NAMEFIELDLENGTH  "$MSG_MSGNOTFOUND" "$FRNLDBNAMEL" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_DIRFIELDLENGTH   "$MSG_MSGNOTFOUND" "$FRNLDBDIRL" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_INIT0ORA "$MSG_MSGNOTFOUND" "$INITORA" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_INITORA "$MSG_MSGNOTFOUND" "$INITORA1" \
       | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_CONFIGORA "$MSG_MSGNOTFOUND" "$CONFIGORA" \
       | tee -a $DBCRTLOG

# Proceeding to create database
dspmsg $MSG_MSGFILE $MSG_CREATINGDB "$MSG_MSGNOTFOUND" "$FRNLDBNAME" \
       | tee -a $DBCRTLOG

# Perform database creation and initial data load
. ./frnxinll.ora.sh

