#!/bin/ksh
#***********************************************************************
# Digital Library Version 2 - 5765-C86.                                *
# VisualInfo Version 2 Release 3.0 - 5697-250.                         *
# (C) Copyright IBM Corp. 1994,1997.                                   *
# All Rights Reserved.                                                 *
#                                                                      *
# US Government Users Restricted Rights                                *
# Use, duplication or disclosure restricted by GSA ADP Schedule        *
# Contract with IBM Corp.                                              *
# Licensed Materials - Property of IBM                                 *
#***********************************************************************
#!/bin/ksh
#***********************************************************************
#                                                                      *
# Program name  : frnxinll.ora.sh                                      *
#                                                                      *
# Description   : Database creation and load to be run by database     *
#                 administrator.                                       *
#                                                                      *
#***********************************************************************

# Set up log file
DBCRTLOGFILE=/tmp/installdb.log
DBCRTLOG=$DBCRTLOGFILE  > /dev/null 2>&1

# Shutdown database if it is still up and running then delete datafiles
if [[ $DBEXIST = 1 ]]; then
   cnt=`ps -ef|grep $ORACLE_SID|wc -l`
   if [[ "$cnt" > 1 ]]; then
      export ORACLE_SID=$ORACLE_SID
outmsg=`svrmgrl<<- EOF
connect internal
shutdown abort
exit
EOF`
   fi
   # delete exist datafile
   rm $FRNDB_BASE/syst$FRNLDBNAME.dbf > /dev/null 2>&1
   rm $FRNDB_BASE/log?$FRNLDBNAME.dbf > /dev/null 2>&1
   rm $FRNDB_BASE/ctr*.ctl > /dev/null 2>&1
   rm $FRNDB_BASE/user*.dbf > /dev/null 2>&1
   rm $FRNDB_BASE/temp*.dbf > /dev/null 2>&1
   rm $FRNDB_BASE/rbs*.dbf > /dev/null 2>&1
   rm $FRNDB_BASE/obj*.dbf > /dev/null 2>&1
fi

################################
# create database $FRNLDBNAME
################################
#create a temporary file, createdb_$FRNLDBNAME.sh
FILENAME=$FRNDB_BASE/createdb_$FRNLDBNAME.sh
CREATEDB=$FRNDB_BASE/createdb_$FRNLDBNAME.sql
echo "export ORACLE_SID=$FRNLDBNAME \n" >  $FILENAME
echo "svrmgrl command=@$CREATEDB\n"  >> $FILENAME
chmod u+x $FILENAME
. $FILENAME

if [[ $? -eq 0 ]]; then  #create database successfully
   # Finished creating Library Server database $FRNLDBNAME
   dspmsg $MSG_MSGFILE $MSG_CREATELSDBDONE "$MSG_MSGNOTFOUND" "$FRNLDBNAME" \
        | tee -a $DBCRTLOG
   rm $FILENAME > /dev/null 2>&1
   cp /tmp/$FRNLDBNAME.tmp /tmp/createdb.log
   rm /tmp/$FRNLDBNAME.tmp

# create user
svrmgrl<<- EOF
connect internal;
create user $FRNUSERID identified by $FRNPASSWD
    default tablespace objtbl
    quota unlimited on objtbl
    quota unlimited on objndx
    temporary tablespace temp;
grant create session, alter session, create table, create view to $FRNUSERID;
exit;
EOF

   if [[ $? -eq 0 ]]; then   #create user successfully
      # Finished creating user $FRNUSERID for database $FRNLDBNAME
      dspmsg $MSG_MSGFILE $MSG_CREATEUSERDONE "$MSG_MSGNOTFOUND" "$FRNUSERID" \
        "$FRNLDBNAME" | tee -a $DBCRTLOG

###########################################
# create $CREATETBL for default data
###########################################

sed "s/FRNLDBVALUEL/${FRNLDBVALUEL}/" frnxinlc.ora > /tmp/frnxinlc.ora.new
sed "s/FRNLDBNAMEL/${FRNLDBNAMEL}/" /tmp/frnxinlc.ora.new > /tmp/frnxinlc.ora.tmp
cp /tmp/frnxinlc.ora.tmp /tmp/frnxinlc.ora.new
sed "s/FRNLDBDIRL/${FRNLDBDIRL}/" /tmp/frnxinlc.ora.new > /tmp/frnxinlc.ora.tmp
cp /tmp/frnxinlc.ora.tmp /tmp/frnxinlc.ora.new
sed "s/FRNLDBLABELL/${FRNLDBLABELL}/" /tmp/frnxinlc.ora.new > /tmp/frnxinlc.ora.tmp
cp /tmp/frnxinlc.ora.tmp /tmp/frnxinlc.ora.new

sed "s/FRNUSERID/${FRNUSERID}/" frnxinll.ora > /tmp/frnxinll.ora.tmp
cp /tmp/frnxinll.ora.tmp /tmp/frnxinll.ora.new

CREATETBL=$FRNDB_BASE/crttbl.sql
printf "\nspool /tmp/createtbl.log\n" > $CREATETBL
cat /tmp/frnxinlc.ora.new >> $CREATETBL
cat /tmp/frnxinll.ora.new >> $CREATETBL
echo "update sbtobjectserver set objservname='$FRNODBNAME' where objservcode=1;" >> $CREATETBL
printf "\nspool off\n" >> $CREATETBL
printf  "\nexit;\n" >> $CREATETBL

rm /tmp/frnxinlc.ora.tmp
rm /tmp/frnxinlc.ora.new

rm /tmp/frnxinll.ora.tmp
rm /tmp/frnxinll.ora.new

svrmgrl<<- EOF
connect $FRNUSERID/$FRNPASSWD
@$CREATETBL
EOF

      if [[ $? -eq 0 ]]; then #create tables successfully
         # Finished creating tables for Library Server $FRNLDBNAME
         dspmsg $MSG_MSGFILE $MSG_CREATELSTBLDONE "$MSG_MSGNOTFOUND" \
                "$FRNLDBNAME" | tee -a $DBCRTLOG
      else
         # Error creating database tables.  Return code=$?
         dspmsg $MSG_MSGFILE $MSG_CREATETABLEERROR "$MSG_MSGNOTFOUND" "$?" \
                | tee -a $DBCRTLOG
         exit 1
      fi #end of create tables successfully
   else
      # Error occurred while creating user $FRNUSERID, Return code=$?
      dspmsg $MSG_MSGFILE $MSG_CREATEUSERERROR "$MSG_MSGNOTFOUND" "$FRNUSERID" "$?" \
        "$FRNUSERID"  | tee -a $DBCRTLOG
      exit 1
   fi  #end of create user
else
    # Error creating database $FRNLDBNAME.  Return Code =$?
    dspmsg $MSG_MSGFILE $MSG_DBCREATEERROR "$MSG_MSGNOTFOUND" "$FRNLDBNAME" "$?" \
        "$?" | tee -a $DBCRTLOG
#   delete obj.var file if database creation failed
#   rm $VARFILE
    exit 1
fi  #end of create database

cat /tmp/createtbl.log >>  /tmp/createdb.log
# The database creation log is /tmp/createdb.log
dspmsg $MSG_MSGFILE $MSG_DBCREATIONLOG "$MSG_MSGNOTFOUND" "/tmp/createdb.log" \
        | tee -a $DBCRTLOG
# echo "\nThe tables creation log is /tmp/createtbl.log "
dspmsg $MSG_MSGFILE $MSG_TBCREATIONLOG "$MSG_MSGNOTFOUND" \
        "/tmp/createtbl.log" | tee -a $DBCRTLOG
# echo "\nThe log file for this installation is $DBCRTLOG "
dspmsg $MSG_MSGFILE $MSG_LOGFILE "$MSG_MSGNOTFOUND" "$DBCRTLOG" \
        | tee -a $DBCRTLOG

#create file startdbm.sh, stopdbm.sh for startup
#or shutdown database
FRNSTARTUP=$FRNDB_BASE/startdbm.sh
echo FRNLDBNAME=$FRNLDBNAME > $FRNSTARTUP

if [[ $? -eq 0 ]]; then
   cat frnstart.libdbi >> $FRNSTARTUP
   if [[ $? -eq 0 ]]; then
      chmod u+x $FRNSTARTUP
   else
      # echo "\n File $FRNSTARTUP creation error.  Error code=$?"
      dspmsg $MSG_MSGFILE $MSG_FILECREATEERROR "$MSG_MSGNOTFOUND" \
        "$FRNSTARTUP" "$?" | tee -a $DBCRTLOG
      exit 1
   fi
else
   # echo "\n File $FRNSTARTUP creation error.  Error code=$?"
   dspmsg $MSG_MSGFILE $MSG_FILECREATEERROR "$MSG_MSGNOTFOUND" \
        "$FRNSTARTUP" "$?" | tee -a $DBCRTLOG
   exit 1
fi
FRNSTOP=$FRNDB_BASE/stopdbm.sh
echo FRNLDBNAME=$FRNLDBNAME > $FRNSTOP
if [[ $? -eq 0 ]]; then
   cat frnstop.libdbi >> $FRNSTOP
   if [[ $? -eq 0 ]]; then
      chmod u+x $FRNSTOP
   else
      # echo "\n File $FRNSTOP creation error.  Error code=$?"
      dspmsg $MSG_MSGFILE $MSG_FILECREATEERROR "$MSG_MSGNOTFOUND" \
        "$FRNSTOP" "$?" | tee -a $DBCRTLOG
      exit 1
   fi
else
   # echo "\n File $FRNSTOP creation error.  Error code=$?"
   dspmsg $MSG_MSGFILE $MSG_FILECREATEERROR "$MSG_MSGNOTFOUND" \
        "$FRNSTOP" "$?" | tee -a $DBCRTLOG
   exit 1
fi

# Terminate the database process

return

