#!/bin/ksh
#***********************************************************************
# Digital Library Version 2 - 5765-C86.                                *
# VisualInfo Version 2 Release 3.0 - 5697-250.                         *
# (C) Copyright IBM Corp. 1994,1997.                                   *
# All Rights Reserved.                                                 *
#                                                                      *
# US Government Users Restricted Rights                                *
# Use, duplication or disclosure restricted by GSA ADP Schedule        *
# Contract with IBM Corp.                                              *
# Licensed Materials - Property of IBM                                 *
#***********************************************************************
#!/bin/ksh
#***********************************************************************
#                                                                      *
# Program name  : frnxinls.ora.sh                                      *
#                                                                      *
# Description   : Database creation prep to be run by database         *
#                 administrator.                                       *
#                                                                      *
#***********************************************************************

# FRNROOT should already be set

# Setup message variables
. $FRNROOT/frnxcosm.sh

# Set up log file
DBCRTLOGFILE=/tmp/dbfile.log
cat /dev/null > $DBCRTLOGFILE
DBCRTLOG=$DBCRTLOGFILE > /dev/null 2>&1

# Ensure that only the oracle user performs creation and setup of database
user=`whoami`
if [[ $user != "oracle" ]]; then
   # echo "\nThe user $user may not perform this installation function."
   # echo "  Only the oracle user may perform creation and set-up of the "
   # echo "  database.  Database creation terminated abnormally. \n"
   dspmsg $MSG_MSGFILE $MSG_USERCANNOTINSTALL "$MSG_MSGNOTFOUND" "$user" \
        | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_ORACLEMUSTCREATEDB "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_DBCREATEABEND "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   exit 1
fi # end of if current user is not oracle

# Check ORACLE_HOME
if [[ "$ORACLE_HOME" = "" ]]; then
   # echo "\nPlease set up ORACLE_HOME. "
   dspmsg $MSG_MSGFILE $MSG_ORACLEHOMENOTSET "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   exit 1
fi

# Get a valid database name from the installer
VALIDDB=0; # reset edit switch
getinput=1
if [[ "$1" != "" ]]; then
   getinput=0
fi # endof if database name was entered on command line
until [[ "$VALIDDB" = 1 ]]; do
   if [[ getinput -ne 0 ]]; then
      # Determine the name of the database to create
      # echo "\nEnter the name of the database you want to create,"
      # echo "  or press enter to choose the default of LIBSRVRX. : "
      dspmsg $MSG_MSGFILE $MSG_ENTERDBNAME "$MSG_MSGNOTFOUND" "LIBSRVRX" \
        | tee -a $DBCRTLOG
      read dbname
      typeset -u dbname
      echo $dbname >> $DBCRTLOG
      if [[ -z "$dbname"  ]]; then  # is string missing?
         VALIDDB=1
         # use default server name
         export FRNLDBNAME=LIBSRVRX
         export ORACLE_SID=LIBSRVRX
      else
         # installer entered server name
         # check to make sure length does not exceed 8 characters+newline
         if
            echo "$dbname" | wc -c | awk '{ if ($1 > 9)
              {
                  exit(1)
              }
              else {
                  exit(0)
                   }
              }'
         then
            VALIDDB=1
            typeset -u dbname
            export FRNLDBNAME=$dbname
            export ORACLE_SID=$dbname
         else
            # echo "\nDatabase name cannot exceed 8 characters \n"
            dspmsg $MSG_MSGFILE $MSG_DBNAMETOOLONG "$MSG_MSGNOTFOUND" \
                "$dbname" | tee -a $DBCRTLOG
            VALIDDB=1
            exit 1
         fi  # end if echo to determine db name length
      fi     # end of if answer is missing
   else
      # Database name was entered on command line
      # Check to make sure length does not exceed 8 characters+newline
      if
         echo "$1" | wc -c | awk '{ if ($1 > 9)
         {
            exit(1)
         }
         else
         {
            VALIDDB=1
            exit(0)
         }
      }'
      then
         dbname=$1
         typeset -u dbname
         export FRNLDBNAME=$dbname
         export ORACLE_SID=$dbname
         VALIDDB=1
      else
         # echo "\nDatabase name cannot exceed 8 characters \n"
         dspmsg $MSG_MSGFILE $MSG_DBNAMETOOLONG "$MSG_MSGNOTFOUND" "$1" \
                | tee -a $DBCRTLOG
         VALIDDB=1
         exit 1
      fi # end of if echo to determine database name length
   fi # end of if database name was not entered on command line
   VARFILE=$ORACLE_HOME/dbs/$FRNLDBNAME.var
   echo DBNAME=$FRNLDBNAME > $VARFILE
done  # end of until do loop

# Get the Library Server pathname
VALIDDB=0
until [[ "$VALIDDB" = 1 ]]; do
     # echo "\nEnter path name for the Library Server database"
     # echo "  or press enter to accept the default path "
     # echo "  $ORACLE_HOME/dbs/$FRNLDBNAME : "
     dspmsg $MSG_MSGFILE $MSG_ENTERLSDBPATH "$MSG_MSGNOTFOUND" \
        "$ORACLE_HOME/dbs/$FRNLDBNAME" | tee -a $DBCRTLOG
     read answer
     echo $answer >> $DBCRTLOG
     if [[ -z "$answer" ]]; then
        VALIDDB=1
        # Use default pathname
        FRNDB_BASE=$ORACLE_HOME/dbs/$FRNLDBNAME
     else
        VALIDDB=1
        FRNDB_BASE=$answer
     fi
     if [[ -d $FRNDB_BASE && -x $FRNDB_BASE ]];
     then
        # echo "\nDirectory $FRNDB_BASE exists."
        dspmsg $MSG_MSGFILE $MSG_DIRECTORYEXISTS "$MSG_MSGNOTFOUND" \
                "$FRNDB_BASE" | tee -a $DBCRTLOG
     else
        mkdir $FRNDB_BASE > /dev/null 2>&1
        VALIDDB=1
        if [[ $? -eq 0 ]]; then     #create $FRNDB_BASE is successful
           # echo "\nDirectory $FRNDB_BASE did not exist, the installation"
           # echo "  program created a $FRNDB_BASE directory. "
           dspmsg $MSG_MSGFILE $MSG_DIRECTORYCREATED "$MSG_MSGNOTFOUND" \
                "$FRNDB_BASE" "$FRNDB_BASE"  | tee -a $DBCRTLOG
        else
           # echo "\nCreate directory $FRNDB_BASE failed, return code $?"
           dspmsg $MSG_MSGFILE $MSG_MKDIRFAILED "$MSG_MSGNOTFOUND" \
                "$FRNDB_BASE failed" "$?" | tee -a $DBCRTLOG
           exit 1
        fi
     fi
     echo PATH=$FRNDB_BASE >> $VARFILE
done

# Check if mirrored backup is necessary
VALIDDB=0
until [[ "$VALIDDB" = 1 ]]; do
     # echo "\nDo you need mirrored backup files done by Oracle?"
     # echo "  If yes, type Y. If no, type any other key for no  : \c"
     dspmsg $MSG_MSGFILE $MSG_MIRRORED "$MSG_MSGNOTFOUND" \
            | tee -a $DBCRTLOG
     dspmsg $MSG_MSGFILE $MSG_ENTERYESORNO "$MSG_MSGNOTFOUND" \
            | tee -a $DBCRTLOG
     read answer
     echo $answer >> $DBCRTLOG
     if [[    "$answer" != $NLS_YES1
           && "$answer" != $NLS_YES2
           && "$answer" != $NLS_YES3
           && "$answer" != $NLS_YES4 ]]; then
        CREATE_BACKUP=0
        VALIDDB=1
     else
        # echo "\nMirrored database full path:"
        dspmsg $MSG_MSGFILE $MSG_ENTERMIRRORDBPATH "$MSG_MSGNOTFOUND" \
               | tee -a $DBCRTLOG
        read answer
        echo $answer >> $DBCRTLOG
        FRNDB_BACKUP_BASE=$answer
        if [[ -d $FRNDB_BACKUP_BASE ]]; then
           # echo "\nBackup directory $FRNDB_BACKUP_BASE already exists."
           dspmsg $MSG_MSGFILE $MSG_BACKUPDIREXISTS "$MSG_MSGNOTFOUND" \
                "$FRNDB_BACKUP_BASE" | tee -a $DBCRTLOG
           VALIDDB=1
           CREATE_BACKUP=1
        else
           mkdir $FRNDB_BACKUP_BASE > /dev/null 2>&1
           if [[ $? -eq 0 ]]; then
              # echo "\nBackup directory does not exist, the installation "
              # echo "  program created a $FRNDB_BACKUP_BASE backup directory."
              dspmsg $MSG_MSGFILE $MSG_NOBACKUPDIR "$MSG_MSGNOTFOUND" \
                    "$FRNDB_BACKUP_BASE" | tee -a $DBCRTLOG
              CREATE_BACKUP=1
              VALIDDB=1
           else
              # echo "\nCreate backup directory failed, return code $?"
              dspmsg $MSG_MSGFILE $MSG_MKBACKUPDIRFAILED "$MSG_MSGNOTFOUND" \
                     "$?" | tee -a $DBCRTLOG
              exit 1
           fi
        fi
     fi
done

CREATEDB=$FRNDB_BASE/createdb_$FRNLDBNAME.sql
cat /dev/null > $CREATEDB
if [[ $? -ne 0 ]]; then
   # echo "Can not create $CREATEDB, exit"
   dspmsg $MSG_MSGFILE $MSG_NOTCREATED "$MSG_MSGNOTFOUND" "$CREATEDB" \
          | tee -a $DBCRTLOG
   exit 1
fi
cat /dev/null > /tmp/$FRNLDBNAME.tmp
print "set termout on" >> $CREATEDB
print "set echo on" >> $CREATEDB
print "spool /tmp/$FRNLDBNAME.tmp" >> $CREATEDB
print "connect internal" >> $CREATEDB
print "startup nomount" >> $CREATEDB
print "create database $FRNLDBNAME" >> $CREATEDB
print "character set \"US7ASCII\"" >> $CREATEDB
if [[ "$CREATE_BACKUP" = 0 ]];
   then
   print "logfile group 1" >> $CREATEDB
   print "         ('$FRNDB_BASE/log1$FRNLDBNAME.dbf') size 500K," >> $CREATEDB
   print "        group 2" >> $CREATEDB
   print "         ('$FRNDB_BASE/log2$FRNLDBNAME.dbf') size 500K," >> $CREATEDB
   print "        group 3" >> $CREATEDB
   print "         ('$FRNDB_BASE/log3$FRNLDBNAME.dbf') size 500K" >> $CREATEDB
else
   if [[ "$CREATE_BACKUP" = 1 ]];
   then
    rm $FRNDB_BACKUP_BASE/*.dbf > /dev/null 2>&1
    rm $FRNDB_BACKUP_BASE/*.ctl > /dev/null 2>&1
     print "logfile group 1 ('$FRNDB_BASE/log1$FRNLDBNAME.dbf'," >> $CREATEDB
     print "                 '$FRNDB_BACKUP_BASE/log1$FRNLDBNAME.dbf')" >> $CREATEDB
     print "                  size 500K," >> $CREATEDB
     print "        group 2 ('$FRNDB_BASE/log2$FRNLDBNAME.dbf'," >> $CREATEDB
     print "                 '$FRNDB_BACKUP_BASE/log2$FRNLDBNAME.dbf')" >> $CREATEDB
     print "                  size 500K," >> $CREATEDB
     print "        group 3 ('$FRNDB_BASE/log3$FRNLDBNAME.dbf'," >> $CREATEDB
     print "                 '$FRNDB_BACKUP_BASE/log3$FRNLDBNAME.dbf')" >> $CREATEDB
     print "                  size 500K" >> $CREATEDB
  fi
fi
print "        datafile '$FRNDB_BASE/syst$FRNLDBNAME.dbf' size 50M;" >> $CREATEDB
print "create rollback segment r0 tablespace system" >> $CREATEDB
print "storage (initial 16k next 16k minextents 2 maxextents 20);" >> $CREATEDB
print "@$ORACLE_HOME/rdbms/admin/catalog.sql;" >> $CREATEDB
print "@$ORACLE_HOME/rdbms/admin/catproc.sql;" >> $CREATEDB
print "alter rollback segment r0 online;" >> $CREATEDB
print "create tablespace rbs datafile" >> $CREATEDB
print "                   '$FRNDB_BASE/rbs01.dbf'   size 8M" >> $CREATEDB
print "       default storage (" >> $CREATEDB
print "                         initial      128k" >> $CREATEDB
print "                         next         128k" >> $CREATEDB
print "                         pctincrease    0" >> $CREATEDB
print "                         minextents     2);" >> $CREATEDB
print "create tablespace temp datafile" >> $CREATEDB
print "     '$FRNDB_BASE/temp01.dbf'  size 8M" >> $CREATEDB
print "       default storage (" >> $CREATEDB
print "                         initial      256k" >> $CREATEDB
print "                         next         256k" >> $CREATEDB
print "                         pctincrease    0);" >> $CREATEDB
print "create tablespace users datafile" >> $CREATEDB
print "     '$FRNDB_BASE/user01.dbf'  size 5M;" >> $CREATEDB
print "create rollback segment r01 tablespace rbs;" >> $CREATEDB
print "create rollback segment r02 tablespace rbs;" >> $CREATEDB
print "create rollback segment r03 tablespace rbs;" >> $CREATEDB
print "create rollback segment r04 tablespace rbs;" >> $CREATEDB
print "alter rollback segment r01 online;" >> $CREATEDB
print "alter rollback segment r02 online;" >> $CREATEDB
print "alter rollback segment r03 online;" >> $CREATEDB
print "alter rollback segment r04 online;" >> $CREATEDB
print "alter rollback segment r0 offline;" >> $CREATEDB
print "drop rollback segment r0;" >> $CREATEDB
print "alter user sys temporary tablespace temp;" >> $CREATEDB
print "create tablespace objtbl datafile" >> $CREATEDB
print "     '$FRNDB_BASE/objtbl01.dbf' size 5M;" >> $CREATEDB
print "create tablespace objndx datafile" >> $CREATEDB
print "     '$FRNDB_BASE/objndx01.dbf' size 3M;" >> $CREATEDB

# Create init file
CONFIGORA=$ORACLE_HOME/dbs/config$FRNLDBNAME.ora
INITORA=$ORACLE_HOME/dbs/init$FRNLDBNAME\_0.ora
INITORA1=$ORACLE_HOME/dbs/init$FRNLDBNAME.ora
echo CONFIGORA=$CONFIGORA >> $VARFILE
echo INITORA=$INITORA >> $VARFILE
echo INITORA1=$INITORA1 >> $VARFILE

# Check if $INITORA/$CONFIGORA already exist
if [[ -a $INITORA ]]; then
   rm $INITORA
fi
if [[ -a $INITORA1 ]]; then
   rm $INITORA1
fi
if [[ -a $CONFIGORA ]]; then
   rm $CONFIGORA
fi

# Create INITORA file
print "ifile=$ORACLE_HOME/dbs/config$FRNLDBNAME.ora" >> $INITORA
print "db_files = 20" >> $INITORA
print "db_file_multiblock_read_count = 8" >> $INITORA
print "db_block_buffers = 200" >> $INITORA
print "shared_pool_size = 3500000" >> $INITORA
print "log_checkpoint_interval = 10000" >> $INITORA
print "processes = 50" >> $INITORA
print "dml_locks = 100" >> $INITORA
print "log_buffer = 8192" >> $INITORA
print "sequence_cache_entries = 10" >> $INITORA
print "sequence_cache_hash_buckets = 10" >> $INITORA
print "sql_trace = true" >> $INITORA
print "timed_statistics = true" >> $INITORA
print "max_dump_file_size = 10240" >> $INITORA
print 'mts_dispatchers = "ipc,1"' >> $INITORA
print "mts_max_dispatchers = 10" >> $INITORA
print "mts_servers = 1" >> $INITORA
print "mts_max_servers = 10" >> $INITORA
print "mts_service = $FRNLDBNAME" >> $INITORA
print "mts_listener_address=\"(ADDRESS=(PROTOCOL=ipc)(KEY=$FRNLDBNAME))\"" >> $INITORA

# Create CONFIGORA file
if [[ "$CREATE_BACKUP" = 0 ]];
   then
   print "control_files=("  >> $CONFIGORA
   print "     $FRNDB_BASE/ctr101.ctl)"  >> $CONFIGORA
else
   if [[ "$CREATE_BACKUP" = 1 ]];
      then
      print "control_files=("  >> $CONFIGORA
      print "     $FRNDB_BASE/ctr101.ctl,"  >> $CONFIGORA
      print "     $FRNDB_BACKUP_BASE/ctr102.ctl)"  >> $CONFIGORA
   fi
fi
print "background_dump_dest=$FRNDB_BASE/log"  >>$CONFIGORA
print "core_dump_dest=$FRNDB_BASE/log"  >> $CONFIGORA
print "user_dump_dest=$FRNDB_BASE/log"  >> $CONFIGORA
print "db_name=$FRNLDBNAME"  >> $CONFIGORA

cp $INITORA $INITORA1
print "rollback_segments=(r01,r02,r03,r04)" >> $INITORA1

if [[ $? -eq 0 ]]; then
   if [[ "$SEL" -ne 3 ]]; then
      # Display list of files that have been created
      dspmsg $MSG_MSGFILE $MSG_FILESCREATED "$MSG_MSGNOTFOUND" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_DBLOGFILE "$MSG_MSGNOTFOUND" "$DBCRTLOG" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_FILEFORDBCREATE "$MSG_MSGNOTFOUND" "$VARFILE" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_FILEFORDBCREATEMOD "$MSG_MSGNOTFOUND" "$CREATEDB" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_FILEFORDBUSE "$MSG_MSGNOTFOUND" "$CONFIGORA" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_FILEFORDBCREATEMOD "$MSG_MSGNOTFOUND" "$INITORA" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_FILEFORDBUSE "$MSG_MSGNOTFOUND" "$INITORA1" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_LSDBCREATEPARMSOK "$MSG_MSGNOTFOUND" \
             | tee -a $DBCRTLOG
   fi
else
   # File creation failed
   dspmsg $MSG_MSGFILE $MSG_FILECREATEFAILED "$MSG_MSGNOTFOUND" \
          | tee -a $DBCRTLOG
fi

if [[ "$SEL" -eq 3 ]]; then
   # Continue database creation
   . ./frnxinlc.ora.sh
fi

