#!/bin/ksh
#***********************************************************************
# Digital Library Version 2 - 5765-C86.                                *
# VisualInfo Version 2 Release 3.0 - 5697-250.                         *
# (C) Copyright IBM Corp. 1994,1997.                                   *
# All Rights Reserved.                                                 *
#                                                                      *
# US Government Users Restricted Rights                                *
# Use, duplication or disclosure restricted by GSA ADP Schedule        *
# Contract with IBM Corp.                                              *
# Licensed Materials - Property of IBM                                 *
#***********************************************************************
prodname=VI
#BA7018ll
progname=`basename $0`

#------------------------------------------------------------------------------
#  Functions
#------------------------------------------------------------------------------

#------------------------------------------------------------------------------
#  purify() is a function that accepts a pathname as its single argument,
#  and eliminates extraneous slashes, storing the result in the variable
#  newpath.
#------------------------------------------------------------------------------
purify()
{
    oldpath=$1
    tmppath=""

    while [ "$oldpath" != "/" ] && [ "$oldpath" != "." ]
    do
        if [ "$tmppath" = "" ]; then
            tmppath=`basename $oldpath`
        else
            tmppath=`basename $oldpath`'/'$tmppath
        fi
        oldpath=`dirname $oldpath`
    done

    if [ "$oldpath" = "/" ]; then
        echo $tmppath | grep ^/ > /dev/null 2>&1
        if [ $? -ne 0 ]; then
            tmppath='/'$tmppath
        fi
    fi

    newpath=$tmppath
}
#EA7018ll

if [[ "$SEL" = 2 ]]; then
   # Display copyright statement
   cat copyright
fi

#------------------------------------------------------------------------------
#  Setup message variables
#------------------------------------------------------------------------------
. $FRNROOT/frnxcosm.sh

#BA7346.ske
#------------------------------------------------------------------------------
#  Determine if DL or VI
#------------------------------------------------------------------------------
#dlprodfile=$FRNROOT/../Product.DigitalLibrary
#viprodfile=$FRNROOT/../Product.VisualInfo

#if [[ -e $dlprodfile ]]          # if this is for DL rather than VI
#  then prodname=DL               # record DL product name
#  else prodname=VI               # record VI product name
#fi
#EA7346.ske

#------------------------------------------------------------------------------
#  Set up log file
#------------------------------------------------------------------------------
DBCRTLOGFILE=/tmp/installdb.log
cat /dev/null > $DBCRTLOGFILE
DBCRTLOG=$DBCRTLOGFILE  > /dev/null 2>&1

#------------------------------------------------------------------------------
#  Setup Staging default
#------------------------------------------------------------------------------
  DEFAULTSTG=/ubosstg/
  DEFAULTDSTG=/lbosdata/  #11154
  DEFAULTMPT=/

#------------------------------------------------------------------------------
#  Ensure that only the oracle user performs creation and setup of database
#------------------------------------------------------------------------------
user=`whoami`
if [[ $user != "oracle" ]]; then
   #---------------------------------------------------------------------------
   #  The user $user may not perform this installation function.
   #  Only the oracle user may perform creation and set-up of the
   #  database.  Database creation terminated abnormally.
   #---------------------------------------------------------------------------
   dspmsg $MSG_MSGFILE $MSG_USERCANNOTINSTALL "$MSG_MSGNOTFOUND" "$user" \
        | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_ORACLEMUSTCREATEDB "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_DBCREATEABEND "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   echo " "
   echo " "
#BM7097.ske
   dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
          "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
   echo " "
   exit 1
fi

#------------------------------------------------------------------------------
#  check ORACLE_HOME
#------------------------------------------------------------------------------
if [[ "$ORACLE_HOME" = "" ]]; then
   #---------------------------------------------------------------------------
   #  Please set up ORACLE_HOME.
   #---------------------------------------------------------------------------
   dspmsg $MSG_MSGFILE $MSG_ORACLEHOMENOTSET "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   echo " "
   echo " "
#BM7097.ske
   dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
          "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
   echo " "
   exit 1
fi

#------------------------------------------------------------------------------
#  Get a valid database name from the installer
#------------------------------------------------------------------------------
if [[ "$SEL" -ne 3 ]]; then
VALIDDB=0; # reset edit switch
getinput=1
 if [[ "$1" != "" ]]; then
    getinput=0
 fi # endof if database name was entered on command line
 until [[ "$VALIDDB" = 1 ]]; do
    if [[ getinput -ne 0 ]]; then
      #------------------------------------------------------------------------
      #  Enter the name of the database you want to create,
      #  or press enter to choose the default of OBJSRVRX. :
      #------------------------------------------------------------------------
      dspmsg $MSG_MSGFILE $MSG_ENTERDBNAME "$MSG_MSGNOTFOUND" "OBJSRVRX" \
        | tee -a $DBCRTLOG
      read dbname
      typeset -u dbname
      echo $dbname >> $DBCRTLOG
      if [[ -z "$dbname"  ]]; then  # is string missing?
         VALIDDB=1
         # use default server name
         export FRNODBNAME=OBJSRVRX
         export ORACLE_SID=OBJSRVRX
      else
         # installer entered server name
         # check to make sure length does not exceed 8 characters+newline
         if
            echo "$dbname" | wc -c | awk '{ if ($1 > 9)
              {
                  exit(1)
              }
              else {
                  exit(0)
                   }
              }'
         then
            VALIDDB=1
            typeset -u dbname
            export FRNODBNAME=$dbname
            export ORACLE_SID=$dbname
         else
            #------------------------------------------------------------------
            #  Database name cannot exceed 8 characters
            #------------------------------------------------------------------
            dspmsg $MSG_MSGFILE $MSG_DBNAMETOOLONG "$MSG_MSGNOTFOUND" \
                "$dbname" | tee -a $DBCRTLOG
            VALIDDB=1
            echo " "
            echo " "
#BM7097.ske
            dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
                   "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
            echo " "
            exit 1
         fi  # end if echo to determine db name length
      fi     # end of if dbname is missing
   else
      #------------------------------------------------------------------------
      # database name was entered on command line
      # check to make sure length does not exceed 8 characters+newline
      #------------------------------------------------------------------------
      if
         echo "$1" | wc -c | awk '{ if ($1 > 9)
         {
            exit(1)
         }
         else
         {
            VALIDDB=1
            exit(0)
         }
      }'
      then
         dbname=$1
         typeset -u dbname
         export FRNODBNAME=$dbname
         export ORACLE_SID=$dbname
         VALIDDB=1
      else
         #---------------------------------------------------------------------
         #  Database name cannot exceed 8 characters
         #---------------------------------------------------------------------
         dspmsg $MSG_MSGFILE $MSG_DBNAMETOOLONG "$MSG_MSGNOTFOUND" "$dbname" \
                | tee -a $DBCRTLOG
         VALIDDB=1
         echo " "
         echo " "
#BM7097.ske
         dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
                "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
         echo " "
         exit 1
      fi # end of if echo to determine database name length
   fi # end of if database name was not entered on command line
done  # end of until do loop
fi

#------------------------------------------------------------------------------
#  get the userid for create database tables
#------------------------------------------------------------------------------
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
   #---------------------------------------------------------------------------
   #  Please enter the userid for Object Server database
   #  $FRNODBNAME who will be the owner of database tables
   #  or press enter to choose the default, dlossrvr :
   #---------------------------------------------------------------------------
   dspmsg $MSG_MSGFILE $MSG_GETOSDBID "$MSG_MSGNOTFOUND" "$FRNODBNAME" \
        | tee -a $DBCRTLOG #M6814ll
   read answer
   if [[ -z "$answer" ]]; then    # is string missing?
      #------------------------------------------------------------------------
      #  use default database description
      #------------------------------------------------------------------------
      export FRNUSERID=dlossrvr
      VALIDDB=1
   else
      #------------------------------------------------------------------------
      #  check to make sure length does not exceed 8 characters+newline
      #------------------------------------------------------------------------
      if
         echo "$answer" | wc -c | awk '{ if ($1 > 9)
            {
               exit(1)
            }
         else {
               exit(0)
            }
         }'
      then
         VALIDDB=1
         export FRNUSERID=$answer
      else
         #---------------------------------------------------------------------
         #  Database owner id $answer cannot exceed 8 characters
         #---------------------------------------------------------------------
         dspmsg $MSG_MSGFILE $MSG_DBOWNERTOOLONG "$MSG_MSGNOTFOUND" \
                "$answer" | tee -a $DBCRTLOG
      fi
   fi # end of string mistting
done

#------------------------------------------------------------------------------
#  get the password for $FRNUSERID
#------------------------------------------------------------------------------
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
   #---------------------------------------------------------------------------
   #  Please enter the password for userid $FRNUSERID
   #  or press enter to choose the default, oracle. :
   #---------------------------------------------------------------------------
   dspmsg $MSG_MSGFILE $MSG_GETPASSWD "$MSG_MSGNOTFOUND" "$FRNUSERID" \
        | tee -a $DBCRTLOG
   stty -echo
   read answer
   stty echo
   echo
   if [[ -z "$answer" ]]; then    # is string missing?
      #------------------------------------------------------------------------
      #  use default database description
      #------------------------------------------------------------------------
      export FRNPASSWD=oracle
      VALIDDB=1
   else
      #------------------------------------------------------------------------
      #  check to make sure length does not exceed 8 characters+newline
      #------------------------------------------------------------------------
      if
         echo "$answer" | wc -c | awk '{ if ($1 > 9)
            {
               exit(1)
            }
         else {
               exit(0)
            }
         }'
      then
         VALIDDB=1
         export FRNPASSWD=$answer
      else
         #---------------------------------------------------------------------
         #  Password cannot exceed 8 characters
         #---------------------------------------------------------------------
         dspmsg $MSG_MSGFILE $MSG_PASSWORDTOOLONG "$MSG_MSGNOTFOUND" \
                | tee -a $DBCRTLOG
      fi
   fi # end of missing string
done

#------------------------------------------------------------------------------
#  Check if database is local
#
#  Is the object server image installed on this machine?"
#  If yes, type Y.
#  If no, type any other key for no :
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_IMAGEINSTALLED "$MSG_MSGNOTFOUND"
dspmsg $MSG_MSGFILE $MSG_ENTERYESORNO "$MSG_MSGNOTFOUND" "$DB2INSTANCE"
read answer
if [[    "$answer" != $NLS_YES1
      && "$answer" != $NLS_YES2
      && "$answer" != $NLS_YES3
      && "$answer" != $NLS_YES4 ]]; then
   export LOCAL_DB=REMOTE
else
   export LOCAL_DB=LOCAL
fi

#BA7604ll
if [[ $LOCAL_DB = "LOCAL" ]]; then
    #--------------------------------------------------------------------------
    #  Please enter the userid for the object server administrator:
    #--------------------------------------------------------------------------
    dspmsg $MSG_MSGFILE $MSG_GETOSID "$MSG_MSGNOTFOUND" | tee -a $DBCRTLOG
    read os_uid

    #--------------------------------------------------------------------------
    #  Check if os_uid is a member of the same group as user oracle.
    #--------------------------------------------------------------------------
    oracle_gid=`id -g`
    os_gid=`id -G $os_uid`
    echo $os_gid | grep -w $oracle_gid > /dev/null 2>&1

    if [ $? -ne 0 ]; then
        #----------------------------------------------------------------------
        #  os_uid is not a member of user oracle's group.
        #  Please make this correction and try again.
        #----------------------------------------------------------------------
        echo " "
        dspmsg $MSG_MSGFILE $MSG_BADGID "$MSG_MSGNOTFOUND" "$os_uid" \
            | tee -a $DBCRTLOG
        echo " "
        dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
            "$progname"  | tee -a $DBCRTLOG
        echo " "
        exit
    fi
fi
#EA7604ll

#------------------------------------------------------------------------------
#  Check for media feature      
#------------------------------------------------------------------------------
#BM7346.ske
export FRNMEDIA=0

if [[ $prodname = "DL" ]]; then
#EM7346.ske

  dspmsg $MSG_MSGFILE $MSG_MEDIASUPPORT "$MSG_MSGNOTFOUND" 
  read answer
  #BM7504lah
  if [[    "$answer" = $NLS_YES1
        || "$answer" = $NLS_YES2
        || "$answer" = $NLS_YES3
        || "$answer" = $NLS_YES4 ]]; then
  #EM7504lah
     export FRNMEDIA=1

     # Prompt for media server name
     dspmsg $MSG_MSGFILE $MSG_MSNAME "$MSG_MSGNOTFOUND" 
     read FRNMSNAME
     if [[ -z $FRNMSNAME ]]; then
        dspmsg $MSG_MSGFILE $MSG_MSNAME_NOTFOUND "$MSG_MSGNOTFOUND" 
        exit
     fi
     export FRNMSNAME

     # Prompt for media server asset group
     dspmsg $MSG_MSGFILE $MSG_MSGROUP "$MSG_MSGNOTFOUND" 
     read FRNMSGROUP 
     if [[ -z $FRNMSGROUP ]]; then
        dspmsg $MSG_MSGFILE $MSG_MSGROUP_NOTFOUND "$MSG_MSGNOTFOUND" 
        exit
     fi
     export FRNMSGROUP

     # Prompt for media server type
     dspmsg $MSG_MSGFILE $MSG_MSTYPE1 "$MSG_MSGNOTFOUND" 
     dspmsg $MSG_MSGFILE $MSG_MSTYPE2 "$MSG_MSGNOTFOUND"
     read FRNMSTYPE
     if [[ "$FRNMSTYPE" = m || "$FRNMSTYPE" = M ]]; then
        FRNMSTYPE=M
     else
        FRNMSTYPE=V
     fi
     export FRNMSTYPE
  fi

#BA7346.ske
fi
#EA7346.ske

#------------------------------------------------------------------------------
#  Find database path
#------------------------------------------------------------------------------
VARFILE=$ORACLE_HOME/dbs/$FRNODBNAME.var
if [[ -s $VARFILE ]]; then
   FRNDB_BASE=`grep PATH $VARFILE|cut -d= -f2`
   if [[ -d $FRNDB_BASE ]]; then
      export FRNDB_BASE
   else
      #------------------------------------------------------------------------
      #  Database path $FRNDB_BASE does not exist,
      #  file frncrt.dbfile.obj need to be executed first.  Exit.
      #------------------------------------------------------------------------
      dspmsg $MSG_MSGFILE $MSG_NODBPATH "$MSG_MSGNOTFOUND" "$FRNDB_BASE" \
             | tee -a $DBCRTLOG
      echo " "
      echo " "
#BM7097.ske
      dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
             "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
      echo " "
      exit 1
   fi
else
   #---------------------------------------------------------------------------
   #  $VARFILE does not exist, file frncrt.dbfile.obj need to be
   #  executed first.  Exit.
   #---------------------------------------------------------------------------
   dspmsg $MSG_MSGFILE $MSG_NOVARFILE "$MSG_MSGNOTFOUND" "$VARFILE" \
             | tee -a $DBCRTLOG
   echo " "
   echo " "
#BM7097.ske
   dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
          "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
   echo " "
   exit 1
fi

#------------------------------------------------------------------------------
#  Get data base description
#------------------------------------------------------------------------------
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
     #-------------------------------------------------------------------------
     #  Enter the database description (1-30 characters),
     #  or press enter to choose default of
     #  'Object Server Database' :
     #-------------------------------------------------------------------------
     dspmsg $MSG_MSGFILE $MSG_ENTEROSDBDESC "$MSG_MSGNOTFOUND" \
                | tee -a $DBCRTLOG
     read answer
     echo $answer >> $DBCRTLOG
     if [[ -z "$answer"  ]]; then  # is string missing?
        VALIDDB=1
        #----------------------------------------------------------------------
        #  use default server name
        #----------------------------------------------------------------------
        export FRNODBCOMMENT="$NLS_OSDBDESC_DEFAULT"
     else
        #----------------------------------------------------------------------
        #  setup for user entered server description
        #----------------------------------------------------------------------
        VALIDDB=1
        export FRNODBCOMMENT="$answer"
     fi
done

#------------------------------------------------------------------------------
#  check if database exists
#------------------------------------------------------------------------------
if [[ -a $FRNDB_BASE/syst$FRNODBNAME.dbf || -a $FRNDB_BASE/log1$FRNODBNAME.dbf \
                                         || -a $FRNDB_BASE/ctr101.ctl ]];
then
   #---------------------------------------------------------------------------
   #  Database already exists.  Would you like to delete the
   #  old one - path $FRNDB_BASE?
   #  If yes, type Y. 
   #  If no, type any other key for no to exit :
   #---------------------------------------------------------------------------
   dspmsg $MSG_MSGFILE $MSG_DBEXISTS "$MSG_MSGNOTFOUND" "$FRNDB_BASE" \
        | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_ENTERYESORNO "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   read answer
   echo $answer >> $DBCRTLOG
   if [[    "$answer" != $NLS_YES1
         && "$answer" != $NLS_YES2
         && "$answer" != $NLS_YES3
         && "$answer" != $NLS_YES4 ]]; then
      #------------------------------------------------------------------------
      #  don't overwrite old database
      #
      #  Database creation terminated normally.
      #------------------------------------------------------------------------
      dspmsg $MSG_MSGFILE $MSG_DBCREATETERMNORM "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
      echo " "
      echo " "
#BM7097.ske
      dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
             "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
      echo " "
      exit 0

   else
      #------------------------------------------------------------------------
      #  delete existing database
      #------------------------------------------------------------------------
      export DBEXIST=1

#BA7018ll
      #------------------------------------------------------------------------
      #  check to see if there is an instance with this ORACLE_SID
      #
      #  Checking the existence of $FRNODBNAME, please wait ...
      #------------------------------------------------------------------------
      dspmsg $MSG_MSGFILE $MSG_DBEXISTCHECK "$MSG_MSGNOTFOUND" "$FRNODBNAME" \
          | tee -a $DBCRTLOG

      oracle_output=`svrmgrl<<- EOF
      connect internal;
      startup;
      exit;
      EOF`

      started=`echo "$oracle_output" | grep ORA-01081 | wc -l`

      if (( started == 1 )); then
          oracle_output=`svrmgrl<<- EOF
          connect internal;
          shutdown abort;
          exit;
          EOF`
      fi
#EA7018ll
   fi # end if answer is yes
fi

#------------------------------------------------------------------------------
#  create dump log directory
#------------------------------------------------------------------------------
DUMP_LOG=$FRNDB_BASE/log
if [[ -d $DUMP_LOG ]]; then
   #---------------------------------------------------------------------------
   #  Dump log $FRNDB_BASE/log directory already exists
   #---------------------------------------------------------------------------
   dspmsg $MSG_MSGFILE $MSG_DIRECTORYEXISTS "$MSG_MSGNOTFOUND" "$FRNDB_BASE/log"
else
   mkdir $DUMP_LOG > /dev/null 2>&1
   if [[ $? -eq 0 ]]; then
      #------------------------------------------------------------------------
      #  Dump log directory does not exist
      #------------------------------------------------------------------------
      dspmsg $MSG_MSGFILE $MSG_DIRDOESNOTEXISTS "$MSG_MSGNOTFOUND" \
          "$FRNDB_BASE/log"
      dspmsg $MSG_MSGFILE $MSG_DIRCREATED "$MSG_MSGNOTFOUND" "$FRNDB_BASE/log"
      export DUMP_LOG
   else
      #------------------------------------------------------------------------
      #  Create dump log directory failed
      #------------------------------------------------------------------------
      dspmsg $MSG_MSGFILE $MSG_DIRCREATEFAILED "$MSG_MSGNOTFOUND" \
          "$FRNDB_BASE/log"
      echo " "
      echo " "
#BM7097.ske
      dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
             "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
      echo " "
      exit 1
   fi
fi

#------------------------------------------------------------------------------
#  Get Staging Path
#------------------------------------------------------------------------------
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
     #-------------------------------------------------------------------------
     #  Enter the Staging area path,
     #  or press enter to choose the default of $DEFAULTSTG:
     #-------------------------------------------------------------------------
     dspmsg $MSG_MSGFILE $MSG_ENTERSTAGING "$MSG_MSGNOTFOUND" "$DEFAULTSTG" \
        | tee -a $DBCRTLOG
     read answer
     echo $answer >> $DBCRTLOG
     if [[ -z "$answer"  ]]; then  # is string missing?
        VALIDDB=1
        #----------------------------------------------------------------------
        #  use default
        #----------------------------------------------------------------------
        export FRNOBJPATH=$DEFAULTSTG
     else
        #----------------------------------------------------------------------
        #  setup for user entered value
        #----------------------------------------------------------------------
        VALIDDB=1
        purify $answer #A7018ll
        export FRNOBJPATH="${newpath%/}/" #M7018ll
     fi  # end of if dbname is missing

     #-------------------------------------------------------------------------
     #  Create Staging directory, if database is local
     #-------------------------------------------------------------------------
     if [[ $LOCAL_DB = "LOCAL" ]]; then
        if test -d $FRNOBJPATH
        then
#BA7018ll
           #-------------------------------------------------------------------
           #  Make sure $FRNOBJPATH is writeable
           #-------------------------------------------------------------------
           touch $FRNOBJPATH/tmp.$$ > /dev/null 2>&1
   
           if [ $? -ne 0 ]
           then
              #----------------------------------------------------------------
              #  ERROR - cannot write in $FRNOBJPATH
              #
              #  You need to have read/write/execute permissions for the
              #  staging area.  Make sure that the access modes for each
              #  directory in your path are
              #
              #      read/write/execute
              #
              #  or choose another path that satisfies this criteria.
              #----------------------------------------------------------------
              dspmsg $MSG_MSGFILE $MSG_CANNOTWRITE "$MSG_MSGNOTFOUND" \
                  "$FRNOBJPATH" | tee -a $DBCRTLOG
              dspmsg $MSG_MSGFILE $MSG_STAGINGWRITE "$MSG_MSGNOTFOUND" \
                   | tee -a $DBCRTLOG
              echo " "
              echo " "
#BM7097.ske
              dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
                     "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
              echo " "
              exit 1
           else
              rm $FRNOBJPATH/tmp.$$
           fi
#EA7018ll
           #-------------------------------------------------------------------
           #  $FRNOBJPATH already exists. The installation
           #  program did not create staging directory.
           #-------------------------------------------------------------------
           dspmsg $MSG_MSGFILE $MSG_STAGINGEXISTS "$MSG_MSGNOTFOUND" \
                "$FRNOBJPATH" "$FRNOBJPATH" | tee -a $DBCRTLOG
           chmod -R 775 $FRNOBJPATH > /dev/null 2>&1 #A7718ll
        else
           mkdir -p "${FRNOBJPATH%/}" > /dev/null 2>&1
           chmod -R 775 $FRNOBJPATH > /dev/null 2>&1 #A7604ll

           if [[ $? -eq 0 ]]; then
              #----------------------------------------------------------------
              #  The $FRNOBJPATH directory did not exist.  The installation
              #  program created a $FRNOBJPATH directory.
              #----------------------------------------------------------------
              dspmsg $MSG_MSGFILE $MSG_DIRECTORYCREATED "$MSG_MSGNOTFOUND" \
                        "$FRNOBJPATH" "$FRNOBJPATH" | tee -a $DBCRTLOG
              VALIDDB=1
           else
              #----------------------------------------------------------------
              #  Create directory $FRNOBJPATH failed, return code $?
              #
              #  You need to have read/write/execute permissions for the
              #  staging area.  Make sure that the access modes for each
              #  directory in your path are
              #
              #      read/write/execute
              #
              #  or choose another path that satisfies this criteria.
              #----------------------------------------------------------------
              dspmsg $MSG_MSGFILE $MSG_DIRCREATEFAILED "$MSG_MSGNOTFOUND" \
                  "$FRNOBJPATH" | tee -a $DBCRTLOG
              echo " "
              echo " "
#BM7097.ske
              dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
                     "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
              echo " "
              exit 1
           fi
        fi
     fi
done  # end of until loop

#------------------------------------------------------------------------------
#  Get Mount Point
#------------------------------------------------------------------------------
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
     #-------------------------------------------------------------------------
     #  Enter the mount point of the filesystem on which
     #  you want to define the destaging area or
     #  press enter to choose the default of $DEFAULTMPT :
     #-------------------------------------------------------------------------
     dspmsg $MSG_MSGFILE $MSG_DESTAGINGMTPT "$MSG_MSGNOTFOUND" "$DEFAULTMPT" \
        | tee -a $DBCRTLOG
     read answer
     echo $answer >> $DBCRTLOG
     if [[ -z "$answer"  ]]; then  # is string missing?
        VALIDDB=1
        #--------------------------------------------------------------------
        #  use default
        #--------------------------------------------------------------------
        export FRNOBJMPT=$DEFAULTMPT
     else
        #--------------------------------------------------------------------
        #  setup for user entered value
        #--------------------------------------------------------------------
        VALIDDB=1
        if [[ $answer = "/" ]]; then
            export FRNOBJMPT=$answer
        else
            purify $answer #A7018ll
            export FRNOBJMPT=$newpath #M7018ll
        fi
     fi
done

#------------------------------------------------------------------------------
#  Get the path that the destaging path will be attached on
#------------------------------------------------------------------------------
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
     #-------------------------------------------------------------------------
     #  Enter the path that the Destaging area will be attached on,
     #  or press enter to choose the default of $FRNOBJMPT :
     #-------------------------------------------------------------------------
     if [[ $FRNOBJMPT = "/" ]]; then
        dspmsg $MSG_MSGFILE $MSG_ENTERDESTAGING "$MSG_MSGNOTFOUND" \
            "$FRNOBJMPT" "$FRNOBJMPT" | tee -a $DBCRTLOG
     else
        dspmsg $MSG_MSGFILE $MSG_ENTERDESTAGING "$MSG_MSGNOTFOUND" \
            "${FRNOBJMPT}/" "${FRNOBJMPT}/" | tee -a $DBCRTLOG
     fi

     read answer
     echo $answer >> $DBCRTLOG
     if [[ -z "$answer"  ]]; then  # is string missing?
        VALIDDB=1
        #----------------------------------------------------------------------
        #  use default
        #----------------------------------------------------------------------
        export FRNOBJVPATH=$FRNOBJMPT
        VALIDDB=1
        #DEFAULTFG=1 #ssw 10876
     else
        #----------------------------------------------------------------------
        #  setup for user entered value
        #----------------------------------------------------------------------
        if [[ $FRNOBJMPT = "/" ]]; then
           FRNOBJVPATH=$FRNOBJMPT"${answer%/}"
        else
           FRNOBJVPATH=$FRNOBJMPT"/${answer%/}"
        fi
        purify $FRNOBJVPATH #A7018ll
        export FRNOBJVPATH=$newpath #M7018ll
        VALIDDB=1
     fi

     if [[ LOCAL_DB = "LOCAL" ]]; then
        if test -d $FRNOBJVPATH
        then
           VALIDDB=1
           #-------------------------------------------------------------------
           #  $FRNOBJVPATH already exists.  The installation
           #  program did not create directory.
           #-------------------------------------------------------------------
           dspmsg $MSG_MSGFILE $MSG_DIREXISTS "$MSG_MSGNOTFOUND" \
                "$FRNOBJVPATH" | tee -a $DBCRTLOG
           chmod -R 775 $FRNOBJVPATH > /dev/null 2>&1 #A7718ll
        else
           VALIDDB=1
           mkdir -p $FRNOBJVPATH > /dev/null 2>&1
           chmod -R 775 $FRNOBJVPATH > /dev/null 2>&1 #A7604ll

           if [[ $? -eq 0 ]]; then
              #----------------------------------------------------------------
              #  The $FRNOBJVPATH did not exist.  The installation
              #  program created a $FRNOBJVPATH directory.
              #----------------------------------------------------------------
              dspmsg $MSG_MSGFILE $MSG_DIRECTORYCREATED "$MSG_MSGNOTFOUND" \
                  "$FRNOBJVPATH" "$FRNOBJVPATH" | tee -a $DBCRTLOG
           else
              #----------------------------------------------------------------
              #  Cannot create directories for $FRNOBJVPATH.
              #
              #  You need to have read/write/execute permissions for the
              #  destaging area.  Make sure that the access modes for each
              #  directory in your path are
              #
              #      read/write/execute
              #
              #  or choose another path that satisfies this criteria.
              #----------------------------------------------------------------
              dspmsg $MSG_MSGFILE $MSG_CANNOTCREATEDIR "$MSG_MSGNOTFOUND" \
                  "$FRNOBJVPATH" | tee -a $DBCRTLOG
              echo " "
              dspmsg $MSG_MSGFILE $MSG_DESTAGINGWRITE "$MSG_MSGNOTFOUND" \
                  | tee -a $DBCRTLOG
              echo " "
              echo " "
#BM7097.ske
              dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
                     "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
              echo " "
              exit 1
           fi
        fi
     fi
done

#------------------------------------------------------------------------------
#  Complete Destaging Path
#------------------------------------------------------------------------------
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
     #-------------------------------------------------------------------------
     #  Complete the path on which the destaging area will be defined or
     #  press enter to choose the default $FRNOBJVPATH$DEFAULTDSTG :
     #-------------------------------------------------------------------------
     #if [[ $FRNOBJVPATH = "/" ]]; then
     #   dspmsg $MSG_MSGFILE $MSG_DESTAGEPATH "$MSG_MSGNOTFOUND" \
     #       "$DEFAULTDSTG" "" | tee -a $DBCRTLOG
     #else
     #   dspmsg $MSG_MSGFILE $MSG_DESTAGEPATH "$MSG_MSGNOTFOUND" \
     #       "$FRNOBJVPATH$DEFAULTDSTG" "$FRNOBJVPATH" | tee -a $DBCRTLOG
     #fi

     #read answer
     #if [[ -z "$answer"  ]]; then  # is string missing?
     #if [[ "$DEFAULTFG" = 1 ]]; then # ssw 10876
     #   VALIDDB=1
        #----------------------------------------------------------------------
        #  use default
        #----------------------------------------------------------------------
     #   FRNOBJDPATH=$DEFAULTDSTG
     #   export FRNOBJDPATH
     #else
        #----------------------------------------------------------------------
        #  setup for user entered value
        #----------------------------------------------------------------------
        VALIDDB=1
     #   #purify "/$answer" #A7018ll
        #export FRNOBJDPATH="$newpath/" #M7018ll
     #   export FRNOBJDPATH=/LBOSDATA/ #ssw 10876
     #fi

     #-------------------------------------------------------------------------
     #  Create Destaging directory
     #-------------------------------------------------------------------------
     if [[ $FRNOBJVPATH = "/" ]]; then
        DESTAGEDIR=$FRNOBJDPATH #M7018ll
     else
        DESTAGEDIR=$FRNOBJVPATH$FRNOBJDPATH
     fi

     if [[ $LOCAL_DB = "LOCAL" ]]; then
        if test -d $DESTAGEDIR
        then
           #-------------------------------------------------------------------
           #  The $DESTAGEDIR directory already exists.
           #  The installation program did not create
           #  $DESTAGEDIR destaging directory.
           #-------------------------------------------------------------------
           dspmsg $MSG_MSGFILE $MSG_DESTAGINGEXISTS "$MSG_MSGNOTFOUND" \
                "$DESTAGEDIR" "$DESTAGEDIR" | tee -a $DBCRTLOG
           chmod -R 775 $DESTAGEDIR > /dev/null 2>&1 #A7718ll
        else
           mkdir -p $DESTAGEDIR > /dev/null 2>&1
           chmod -R 775 $DESTAGEDIR > /dev/null 2>&1 #A7604ll

           if [[ $? -eq 0 ]]; then
              #----------------------------------------------------------------
              #  The $DESTAGEDIR directory did not exist.
              #  The installation program created $DESTAGEDIR directory.
              #----------------------------------------------------------------
              dspmsg $MSG_MSGFILE $MSG_DIRECTORYCREATED "$MSG_MSGNOTFOUND" \
                  "$DESTAGEDIR" "$DESTAGEDIR" | tee -a $DBCRTLOG
           else
              #----------------------------------------------------------------
              #  Create $DESTAGEDIR failed, return code $?
              #----------------------------------------------------------------
              dspmsg $MSG_MSGFILE $MSG_DIRCREATEFAILED "$MSG_MSGNOTFOUND" \
                  "$DESTAGEDIR"
              echo " "
              echo " "
#BM7097.ske
              dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
                     "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
              echo " "
              exit 1
           fi
        fi
     fi
done  # end of until loop

#------------------------------------------------------------------------------
#  Get File System Device Name
#------------------------------------------------------------------------------
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
     #-------------------------------------------------------------------------
     #  Enter the file system device name on which your destaging area is
     #  defined:
     #-------------------------------------------------------------------------
     dspmsg $MSG_MSGFILE $MSG_DESTAGERMPTFS "$MSG_MSGNOTFOUND" \
         | tee -a $DBCRTLOG
     read answer

     if [[ -z "$answer"  ]]; then  # is string missing?
        VALIDDB=1
        #----------------------------------------------------------------------
        #  Cannot proceed without file system device name, exit
        #----------------------------------------------------------------------
        dspmsg $MSG_MSGFILE $MSG_NOFSNAME "$MSG_MSGNOTFOUND" \
                | tee -a $DBCRTLOG
        echo " "
        echo " "
#BM7097.ske
        dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
               "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
        echo " "
        exit 1
     else
        #----------------------------------------------------------------------
        #  setup for user entered value
        #----------------------------------------------------------------------
        VALIDDB=1
        export FRNOLOGICALNAME=$answer
     fi
done

#------------------------------------------------------------------------------
#  Get library server name
#------------------------------------------------------------------------------
VALIDDB=0; # reset edit switch
until [[ "$VALIDDB" = 1 ]]; do
     #-------------------------------------------------------------------------
     #  Enter the name of the initial Library Server database
     #  you want to reference, or press enter to choose
     #  the default of LIBSRVRX:
     #-------------------------------------------------------------------------
     dspmsg $MSG_MSGFILE $MSG_ENTERLIBSERVER "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
     read libname
     typeset -u libname
     echo $libname >> $DBCRTLOG

     if [[ -z "$libname" ]]; then    # is string missing?
        VALIDDB=1
        #----------------------------------------------------------------------
        #  use default object server name
        #----------------------------------------------------------------------
        export FRNLDBNAME=LIBSRVRX
     else
        #----------------------------------------------------------------------
        #  installer entered library server name
        #  check to make sure length does not exceed 8 characters+newline
        #----------------------------------------------------------------------
        if
           echo "$libname" | wc -c | awk '{ if ($1 > 9)
           {
              exit(1)
           }
        else
           {
              exit(0)
           }
        }'
        then
           VALIDDB=1
           export FRNLDBNAME=$libname
        else
           #-------------------------------------------------------------------
           #  Database name $libname cannot exceed 8 characters.
           #-------------------------------------------------------------------
           dspmsg $MSG_MSGFILE $MSG_DBNAMETOOLONG "$MSG_MSGNOTFOUND" \
                "$libname" | tee -a $DBCRTLOG
        fi # end if echo to determine database name length
     fi # end of if database name is missing
done # end of until do loop

#------------------------------------------------------------------------------
#  Give feedback to the installer
#
#  Database will be created with values:
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_DBCREATEVALUES "$MSG_MSGNOTFOUND" \
    | tee -a $DBCRTLOG
echo " "

#------------------------------------------------------------------------------
#  ORACLE_SID                : $ORACLE_SID
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_ORACLESID "$MSG_MSGNOTFOUND" "$ORACLE_SID" \
    | tee -a $DBCRTLOG

#------------------------------------------------------------------------------
#  Database Path             : $FRNDB_BASE
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_DBPATH "$MSG_MSGNOTFOUND" "$FRNDB_BASE" \
    | tee -a $DBCRTLOG

if [[ "$CREATE_BACKUP" = 1 ]]; then
   #---------------------------------------------------------------------------
   #  Database Backup Path   : $FRNDB_BACKUP_BASE
   #---------------------------------------------------------------------------
   dspmsg $MSG_MSGFILE $MSG_BACKUPPATH "$MSG_MSGNOTFOUND" \
       "$FRNDB_BACKUP_BASE" | tee -a $DBCRTLOG
fi

#------------------------------------------------------------------------------
#  Database Dump Log Path    : $DUMP_LOG
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_DUMPLOGPATH "$MSG_MSGNOTFOUND" "$DUMP_LOG" \
    | tee -a $DBCRTLOG

#------------------------------------------------------------------------------
#  Object Server Name        : $FRNODBNAME
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_OBJSERVERNAME "$MSG_MSGNOTFOUND" "$FRNODBNAME" \
    | tee -a $DBCRTLOG

#------------------------------------------------------------------------------
#  Database Description      : $FRNODBCOMMENT
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_DBDESC "$MSG_MSGNOTFOUND" "$FRNODBCOMMENT" \
    | tee -a $DBCRTLOG

#------------------------------------------------------------------------------
#  Library Server Name       : $FRNLDBNAME
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_LIBSERVERNAME "$MSG_MSGNOTFOUND" "$FRNLDBNAME" \
    | tee -a $DBCRTLOG

#------------------------------------------------------------------------------
#  Staging Path              : $FRNOBJPATH
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_STAGINGPATH "$MSG_MSGNOTFOUND" "$FRNOBJPATH" \
    | tee -a $DBCRTLOG

#------------------------------------------------------------------------------
#  Destaging Path            : $DESTAGEDIR
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_DESTAGINGPATH "$MSG_MSGNOTFOUND" "$DESTAGEDIR" \
    | tee -a $DBCRTLOG

#------------------------------------------------------------------------------
#  Mount Point               : $FRNOBJMPT
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_MTPT "$MSG_MSGNOTFOUND" "$FRNOBJMPT" \
    | tee -a $DBCRTLOG

#------------------------------------------------------------------------------
#  Logical Volume Name       : $FRNOLOGICALNAME
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_LOGICALVOLNAME "$MSG_MSGNOTFOUND" "$FRNOLOGICALNAME" \
    | tee -a $DBCRTLOG

#------------------------------------------------------------------------------
#  init_0.ora                : $INITORA
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_INIT0ORA "$MSG_MSGNOTFOUND" "$INITORA" \
    | tee -a $DBCRTLOG

#------------------------------------------------------------------------------
#  init.ora                  : $INITORA1
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_INITORA "$MSG_MSGNOTFOUND" "$INITORA1" \
    | tee -a $DBCRTLOG

#------------------------------------------------------------------------------
#  config.ora                : $CONFIGORA
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_CONFIGORA "$MSG_MSGNOTFOUND" "$CONFIGORA" \
    | tee -a $DBCRTLOG

#BA7018ll
#------------------------------------------------------------------------------
#  Give the user one last chance to exit
#------------------------------------------------------------------------------
echo " "
echo " "
#BM7097.ske
dspmsg $MSG_MSGFILE $MSG_CORRECTINFO "$MSG_MSGNOTFOUND" | tee -a $DBCRTLOG
dspmsg $MSG_MSGFILE $MSG_DBENTER "$MSG_MSGNOTFOUND" | tee -a $DBCRTLOG
#EM7097.ske
echo " "

read answer

if [ -n "$answer" ]; then
  echo " "
#BM7097.ske
  dspmsg $MSG_MSGFILE $MSG_CHOSEEXIT "$MSG_MSGNOTFOUND" | tee -a $DBCRTLOG
  echo " "
  dspmsg $MSG_MSGFILE $MSG_ENDED "$MSG_MSGNOTFOUND" \
         "$progname"  | tee -a $DBCRTLOG
#EM7097.ske
  echo " "
  exit
fi
#EA7018ll

#------------------------------------------------------------------------------
#  Proceeding to create database $FRNODBNAME.  Please wait...
#------------------------------------------------------------------------------
dspmsg $MSG_MSGFILE $MSG_CREATINGDB "$MSG_MSGNOTFOUND" "$FRNODBNAME" \
        | tee -a $DBCRTLOG

. $FRNROOT/frnxinol.ora.sh #M7018ll

