#!/bin/ksh
#***********************************************************************
# Digital Library Version 2 - 5765-C86.                                *
# VisualInfo Version 2 Release 3.0 - 5697-250.                         *
# (C) Copyright IBM Corp. 1994,1997.                                   *
# All Rights Reserved.                                                 *
#                                                                      *
# US Government Users Restricted Rights                                *
# Use, duplication or disclosure restricted by GSA ADP Schedule        *
# Contract with IBM Corp.                                              *
# Licensed Materials - Property of IBM                                 *
#***********************************************************************
#!/bin/ksh
#**********************************************************************#
# International Business Machines Corporation                          #
# Digital Library Version 2 - 5765-C86.                                #
# VisualInfo Version 2 Release 3.0 - 5697-250.                         #
# (C) Copyright IBM Corp. 1994, 1997                                   #
#**********************************************************************#
#***********************************************************************
# Program name  : frnxinos.ora.sh                                      *
#                                                                      *
# Description   : Database creation prep - to be run by oracle         *
#                 This shell script should be executed after           *
#                 the object server image is installed.                *
#                                                                      *
# Change History:                                                      *
#                                                                      *
#  10/08/97   d7018 ll   create $FRNDB_BASE/log directory              *
#  08/28/97   d5408 lah  NLS (copied Monica's Library Server changes)  *
#  01/20/97   d2641 mnc  Changed to allow NLS Yes/No input.            *
#  12/02/96   d2542 pjs  NLS                                           *
#***********************************************************************

# Display copyright statement
cat copyright

#export FRNROOT=.

# Setup message variables
. $FRNROOT/frnxcosm.sh

# Set up log file
DBCRTLOGFILE=/tmp/dbfile.log
cat /dev/null > $DBCRTLOGFILE
DBCRTLOG=$DBCRTLOGFILE > /dev/null 2>&1

user=`whoami`
if [[ $user != "oracle" ]]; then
   #2542.ll echo "\nThe user $user may not perform this installation function." | tee -a $DBCRTLOG
   #2542.ll echo "  Only the oracle user may perform creation and set-up of the " | tee -a $DBCRTLOG
   #2542.ll echo "  database.  Database creation terminated abnormally. \n" | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_USERCANNOTINSTALL "$MSG_MSGNOTFOUND" "$user" \
        | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_ORACLEMUSTCREATEDB "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_DBCREATEABEND "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   exit 1
fi # end of if current user is not oracle

# check ORACLE_HOME
if [[ "$ORACLE_HOME" = "" ]]; then
   #2542.ll echo "\nPlease set up ORACLE_HOME. " | tee -a $DBCRTLOG
   dspmsg $MSG_MSGFILE $MSG_ORACLEHOMENOTSET "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
   exit 1
fi


# check ORACLE_HOME
if [[ "$ORACLE_HOME" = "" ]]; then
#2542.ll echo "\nPlease set up ORACLE_HOME. "
dspmsg $MSG_MSGFILE $MSG_ORACLEHOMENOTSET "$MSG_MSGNOTFOUND"
   exit 1
fi

# Get a valid database name from the installer
VALIDDB=0; # reset edit switch
getinput=1
if [[ "$1" != "" ]]; then
   getinput=0
fi # endof if database name was entered on command line
until [[ "$VALIDDB" = 1 ]]; do
   if [[ getinput -ne 0 ]]; then
      # determine the name of the database to create
      #2542.ll echo "\nEnter the name of the database you want to create," | tee -a $DBCRTLOG
      #2542.ll echo "  or press enter to choose the default of OBJSRVRX. : \cccccccc" | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_ENTERDBNAME "$MSG_MSGNOTFOUND" "OBJSRVRX" \
        | tee -a $DBCRTLOG
      read dbname
      typeset -u dbname
      echo $dbname >> $DBCRTLOG
      if [[ -z "$dbname"  ]]; then  # is string missing?
         VALIDDB=1
         # use default server name
         export FRNODBNAME=OBJSRVRX
         export ORACLE_SID=OBJSRVRX
      else
         # installer entered server name
         # check to make sure length does not exceed 8 characters+newline
         if
            echo "$dbname" | wc -c | awk '{ if ($1 > 9)
              {
                  exit(1)
              }
              else {
                  exit(0)
                   }
              }'
         then
            VALIDDB=1
            typeset -u dbname
            export FRNODBNAME=$dbname
            export ORACLE_SID=$dbname
         else
            #2542.ll echo "\nDatabase name cannot exceed 8 characters \n" | tee -a $DBCRTLOG
            dspmsg $MSG_MSGFILE $MSG_DBNAMETOOLONG "$MSG_MSGNOTFOUND" \
                "$dbname" | tee -a $DBCRTLOG
            VALIDDB=1
            exit 1
         fi  # end if echo to determine db name length
      fi     # end of if answer is missing
   else

      # database name was entered on command line
      # check to make sure length does not exceed 8 characters+newline
      if
         echo "$1" | wc -c | awk '{ if ($1 > 9)
         {
            exit(1)
         }
         else
         {
            VALIDDB=1
            exit(0)
         }
      }'
      then
         dbname=$1
         typeset -u dbname
         export FRNODBNAME=$dbname
         export ORACLE_SID=$dbname
         VALIDDB=1
      else
         #2542.ll echo "\nDatabase name cannot exceed 8 characters \n" | tee -a $DBCRTLOG
         dspmsg $MSG_MSGFILE $MSG_DBNAMETOOLONG "$MSG_MSGNOTFOUND" "$1" \
                | tee -a $DBCRTLOG
         VALIDDB=1
         exit 1
      fi # end of if echo to determine database name length
   fi # end of if database name was not entered on command line
   VARFILE=$ORACLE_HOME/dbs/$FRNODBNAME.var
   echo DBNAME=$FRNODBNAME > $VARFILE
done  # end of until do loop

#------------------------------------------------------------------------------
#  Get the Object Server pathname
#------------------------------------------------------------------------------
#2542.ll echo "\nEnter path name for the Object Server database" | tee -a $DBCRTLOG
#2542.ll echo "  or press enter to accept the default path " | tee -a $DBCRTLOG
#2542.ll echo "  $ORACLE_HOME/dbs/$FRNODBNAME : \cccccccccccccccccccccccccccccccccccccccccccc" | tee -a $DBCRTLOG

dspmsg $MSG_MSGFILE $MSG_ENTEROSDBPATH "$MSG_MSGNOTFOUND" \
    "$ORACLE_HOME/dbs/$FRNODBNAME" | tee -a $DBCRTLOG
read answer
echo $answer >> $DBCRTLOG

if [[ -z "$answer" ]]; then
    #use default pathname
    FRNDB_BASE=$ORACLE_HOME/dbs/$FRNODBNAME
else
    FRNDB_BASE=$answer
fi

if [[ -d $FRNDB_BASE && -x $FRNDB_BASE ]];
then
    #2542.ll echo "\nDirectory $FRNDB_BASE exists."     | tee -a $DBCRTLOG
    dspmsg $MSG_MSGFILE $MSG_DIRECTORYEXISTS "$MSG_MSGNOTFOUND" \
        "$FRNDB_BASE" | tee -a $DBCRTLOG
else
    mkdir -p $FRNDB_BASE/log > /dev/null 2>&1 #M7018ll
    if [[ $? -eq 0 ]]; then     
        #----------------------------------------------------------------------
        # create $FRNDB_BASE is successful
        #----------------------------------------------------------------------
        #2542.ll echo "\nDirectory $FRNDB_BASE did not exist, the installation" | tee -a $DBCRTLOG
        #2542.ll echo "  program created a $FRNDB_BASE directory. " | tee -a $DBCRTLOG
        dspmsg $MSG_MSGFILE $MSG_DIRECTORYCREATED "$MSG_MSGNOTFOUND" \
            "$FRNDB_BASE" "$FRNDB_BASE"  | tee -a $DBCRTLOG
    else
        #2542.ll echo "\nCreate directory $FRNDB_BASE failed, return code $?" | tee -a $DBCRTLOG
        dspmsg $MSG_MSGFILE $MSG_MKDIRFAILED "$MSG_MSGNOTFOUND" \
            "$FRNDB_BASE failed" "$?" | tee -a $DBCRTLOG
        exit 1
    fi
fi
echo PATH=$FRNDB_BASE >> $VARFILE

#------------------------------------------------------------------------------
#  check if mirrored back is necessary
#------------------------------------------------------------------------------

VALIDDB=0
until [[ "$VALIDDB" = 1 ]]; do
     #2542.ll echo "\nDo you need mirrored backup files done by Oracle?" | tee -a $DBCRTLOG
     #2542.ll echo "  If yes, type Y. If no, type any other key for no  : \c" | tee -a $DBCRTLOG
     dspmsg $MSG_MSGFILE $MSG_MIRRORED "$MSG_MSGNOTFOUND" | tee -a $DBCRTLOG
     dspmsg $MSG_MSGFILE $MSG_ENTERYESORNO "$MSG_MSGNOTFOUND" \
        | tee -a $DBCRTLOG
     read answer
     echo $answer >> $DBCRTLOG
     if [[    "$answer" != $NLS_YES1
           && "$answer" != $NLS_YES2
           && "$answer" != $NLS_YES3
           && "$answer" != $NLS_YES4 ]]; then
        CREATE_BACKUP=0
        VALIDDB=1

     else
        #echo "\nMirrored database full path:" |tee -a $DBCRTLOG
        dspmsg $MSG_MSGFILE $MSG_ENTERMIRRORDBPATH "$MSG_MSGNOTFOUND" \
               | tee -a $DBCRTLOG
        read answer
        echo $answer >> $DBCRTLOG
        FRNDB_BACKUP_BASE=$answer
        if [[ -d $FRNDB_BACKUP_BASE ]]; then
           #2542.ll echo "\nBackup directory $FRNDB_BACKUP_BASE already exists." | tee -a $DBCRTLOG
           dspmsg $MSG_MSGFILE $MSG_BACKUPDIREXISTS "$MSG_MSGNOTFOUND" \
                "$FRNDB_BACKUP_BASE" | tee -a $DBCRTLOG
           VALIDDB=1
           CREATE_BACKUP=1
        else
           mkdir $FRNDB_BACKUP_BASE > /dev/null 2>&1
           if [[ $? -eq 0 ]]; then
              #2542.ll echo "\nBackup directory does not exist, the installation " | tee -a $DBCRTLOG
              #2542.ll echo "  program created a $FRNDB_BACKUP_BASE backup directory.  "                   | tee -a $DBCRTLOG
              dspmsg $MSG_MSGFILE $MSG_NOBACKUPDIR "$MSG_MSGNOTFOUND" \n
                "$FRNDB_BACKUP_BASE" | tee -a $DBCRTLOG
              CREATE_BACKUP=1
              VALIDDB=1
           else
              #2542.ll echo "\nCreate backup directory failed, return code $?" | tee -a $DBCRTLOG
              dspmsg $MSG_MSGFILE $MSG_MKBACKUPDIRFAILED "$MSG_MSGNOTFOUND" \
                "$?" | tee -a $DBCRTLOG
              exit 1
           fi
        fi
     fi
done


CREATEDB=$FRNDB_BASE/createdb_$FRNODBNAME.sql
cat /dev/null > $CREATEDB
if [[ $? -ne 0 ]]; then
   #2542.ll echo "Can not create $CREATEDB, exit"
   dspmsg $MSG_MSGFILE $MSG_NOTCREATED "$MSG_MSGNOTFOUND" "$CREATEDB"
   exit 1
fi
cat /dev/null > /tmp/$FRNODBNAME.tmp
print "set termout on" >> $CREATEDB
print "set echo on" >> $CREATEDB
print "spool /tmp/$FRNODBNAME.tmp" >> $CREATEDB
print "connect internal" >> $CREATEDB
print "startup nomount" >> $CREATEDB
print "create database $FRNODBNAME" >> $CREATEDB
print "character set \"US7ASCII\"" >> $CREATEDB
if [[ "$CREATE_BACKUP" = 0 ]];
   then
   print "logfile group 1" >> $CREATEDB
   print "         ('$FRNDB_BASE/log1$FRNODBNAME.dbf') size 500K," >> $CREATEDB
   print "        group 2" >> $CREATEDB
   print "         ('$FRNDB_BASE/log2$FRNODBNAME.dbf') size 500K," >> $CREATEDB
   print "        group 3" >> $CREATEDB
   print "         ('$FRNDB_BASE/log3$FRNODBNAME.dbf') size 500K" >> $CREATEDB
else
   if [[ "$CREATE_BACKUP" = 1 ]];
   then
    rm $FRNDB_BACKUP_BASE/*.dbf > /dev/null 2>&1
    rm $FRNDB_BACKUP_BASE/*.ctl > /dev/null 2>&1
     print "logfile group 1 ('$FRNDB_BASE/log1$FRNODBNAME.dbf'," >> $CREATEDB
     print "                 '$FRNDB_BACKUP_BASE/log1$FRNODBNAME.dbf')" >> $CREATEDB
     print "                  size 500K," >> $CREATEDB
     print "        group 2 ('$FRNDB_BASE/log2$FRNODBNAME.dbf'," >> $CREATEDB
     print "                 '$FRNDB_BACKUP_BASE/log2$FRNODBNAME.dbf')" >> $CREATEDB
     print "                  size 500K," >> $CREATEDB
     print "        group 3 ('$FRNDB_BASE/log3$FRNODBNAME.dbf'," >> $CREATEDB
     print "                 '$FRNDB_BACKUP_BASE/log3$FRNODBNAME.dbf')" >> $CREATEDB
     print "                  size 500K" >> $CREATEDB
  fi
fi
print "        datafile '$FRNDB_BASE/syst$FRNODBNAME.dbf' size 50M;" >> $CREATEDB
print "create rollback segment r0 tablespace system" >> $CREATEDB
print "storage (initial 16k next 16k minextents 2 maxextents 20);" >> $CREATEDB
print "@$ORACLE_HOME/rdbms/admin/catalog.sql;" >> $CREATEDB
print "@$ORACLE_HOME/rdbms/admin/catproc.sql;" >> $CREATEDB
print "alter rollback segment r0 online;" >> $CREATEDB
print "create tablespace rbs datafile" >> $CREATEDB
print "                   '$FRNDB_BASE/rbs01.dbf'   size 8M" >> $CREATEDB
print "       default storage (" >> $CREATEDB
print "                         initial      128k" >> $CREATEDB
print "                         next         128k" >> $CREATEDB
print "                         pctincrease    0" >> $CREATEDB
print "                         minextents     2);" >> $CREATEDB
print "create tablespace temp datafile" >> $CREATEDB
print "     '$FRNDB_BASE/temp01.dbf'  size 8M" >> $CREATEDB
print "       default storage (" >> $CREATEDB
print "                         initial      256k" >> $CREATEDB
print "                         next         256k" >> $CREATEDB
print "                         pctincrease    0);" >> $CREATEDB
print "create tablespace users datafile" >> $CREATEDB
print "     '$FRNDB_BASE/user01.dbf'  size 5M;" >> $CREATEDB
print "create rollback segment r01 tablespace rbs;" >> $CREATEDB
print "create rollback segment r02 tablespace rbs;" >> $CREATEDB
print "create rollback segment r03 tablespace rbs;" >> $CREATEDB
print "create rollback segment r04 tablespace rbs;" >> $CREATEDB
print "alter rollback segment r01 online;" >> $CREATEDB
print "alter rollback segment r02 online;" >> $CREATEDB
print "alter rollback segment r03 online;" >> $CREATEDB
print "alter rollback segment r04 online;" >> $CREATEDB
print "alter rollback segment r0 offline;" >> $CREATEDB
print "drop rollback segment r0;" >> $CREATEDB
print "alter user sys temporary tablespace temp;" >> $CREATEDB
print "create tablespace objtbl datafile" >> $CREATEDB
print "     '$FRNDB_BASE/objtbl01.dbf' size 5M;" >> $CREATEDB
print "create tablespace objndx datafile" >> $CREATEDB
print "     '$FRNDB_BASE/objndx01.dbf' size 3M;" >> $CREATEDB

#create init file

CONFIGORA=$ORACLE_HOME/dbs/config$FRNODBNAME.ora
INITORA=$ORACLE_HOME/dbs/init$FRNODBNAME\_0.ora
INITORA1=$ORACLE_HOME/dbs/init$FRNODBNAME.ora
echo CONFIGORA=$CONFIGORA >> $VARFILE
echo INITORA=$INITORA >> $VARFILE
echo INITORA1=$INITORA1 >> $VARFILE

#check if $INITORA/$CONFIGORA already exist
if [[ -a $INITORA ]]; then
   rm $INITORA
fi
if [[ -a $INITORA1 ]]; then
   rm $INITORA1
fi
if [[ -a $CONFIGORA ]]; then
   rm $CONFIGORA
fi

# create INITORA file
print "ifile=$ORACLE_HOME/dbs/config$FRNODBNAME.ora" >> $INITORA
print "db_files = 20" >> $INITORA
print "db_file_multiblock_read_count = 8" >> $INITORA
print "db_block_buffers = 200" >> $INITORA
print "shared_pool_size = 3500000" >> $INITORA
print "log_checkpoint_interval = 10000" >> $INITORA
print "processes = 50" >> $INITORA
print "dml_locks = 100" >> $INITORA
print "log_buffer = 8192" >> $INITORA
print "sequence_cache_entries = 10" >> $INITORA
print "sequence_cache_hash_buckets = 10" >> $INITORA
print "sql_trace = true" >> $INITORA
print "timed_statistics = true" >> $INITORA
print "max_dump_file_size = 10240" >> $INITORA
print 'mts_dispatchers = "ipc,1"' >> $INITORA
print "mts_max_dispatchers = 10" >> $INITORA
print "mts_servers = 1" >> $INITORA
print "mts_max_servers = 10" >> $INITORA
print "mts_service = $FRNODBNAME" >> $INITORA
print "mts_listener_address=\"(ADDRESS=(PROTOCOL=ipc)(KEY=$FRNODBNAME))\"" >> $INITORA

# create CONFIGORA file

if [[ "$CREATE_BACKUP" = 0 ]];
   then
   print "control_files=("  >> $CONFIGORA
   print "     $FRNDB_BASE/ctr101.ctl)"  >> $CONFIGORA
else
   if [[ "$CREATE_BACKUP" = 1 ]];
      then
      print "control_files=("  >> $CONFIGORA
      print "     $FRNDB_BASE/ctr101.ctl,"  >> $CONFIGORA
      print "     $FRNDB_BACKUP_BASE/ctr102.ctl)"  >> $CONFIGORA
   fi
fi
print "background_dump_dest=$FRNDB_BASE/log"  >>$CONFIGORA
print "core_dump_dest=$FRNDB_BASE/log"  >> $CONFIGORA
print "user_dump_dest=$FRNDB_BASE/log"  >> $CONFIGORA
print "db_name=$FRNODBNAME"  >> $CONFIGORA

cp $INITORA $INITORA1
print "rollback_segments=(r01,r02,r03,r04)" >> $INITORA1

if [[ $? -eq 0 ]]; then
   if [[ "$SEL" -ne 3 ]]; then
      #printf "\n\nThe following files are created:"
      #printf "\n o   Log file for frncrt.dbfile.obj is $DBCRTLOG"
      #printf "\n o   $VARFILE "
      #printf "\n         - this file will be called by frnxinoc.ora"
      #printf "\n o   $CREATEDB"
      #printf "\n         - for database creation, parameters can be modified"
      #printf "\n o   $CONFIGORA"
      #printf "\n         - for database use"
      #printf "\n o   $INITORA"
      #printf "\n         - for database creation, parameters can be modified"
      #printf "\n o   $INITORA1"
      #printf "\n         - for database use"
      #printf "\n\nIf all parameters are acceptable, select option 2 to complete "
      #printf "\n         object server database creation.\n"
      # Display list of files that have been created
      dspmsg $MSG_MSGFILE $MSG_FILESCREATED "$MSG_MSGNOTFOUND" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_DBLOGFILE "$MSG_MSGNOTFOUND" "$DBCRTLOG" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_FILEFORDBCREATE "$MSG_MSGNOTFOUND" "$VARFILE" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_FILEFORDBCREATEMOD "$MSG_MSGNOTFOUND" "$CREATEDB" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_FILEFORDBUSE "$MSG_MSGNOTFOUND" "$CONFIGORA" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_FILEFORDBCREATEMOD "$MSG_MSGNOTFOUND" "$INITORA" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_FILEFORDBUSE "$MSG_MSGNOTFOUND" "$INITORA1" \
             | tee -a $DBCRTLOG
      dspmsg $MSG_MSGFILE $MSG_LSDBCREATEPARMSOK "$MSG_MSGNOTFOUND" \
             | tee -a $DBCRTLOG

   fi
else
   #printf "\nFile creation failed, exit.\n"
   dspmsg $MSG_MSGFILE $MSG_FILECREATEFAILED "$MSG_MSGNOTFOUND" \
          | tee -a $DBCRTLOG

fi
if [[ "$SEL" -eq 3 ]]; then
   . $FRNROOT/frnxinoc.ora.sh #M7018ll
fi
